
/*******************
 * From src: modules/monitoring/src/js/backup.js
 *******************/
(function () {

  var baseurl = _site_domain + _index_page + '/';

  var nl2br = function(text) {
    return text.replace("\n", "<br>", "g");
  };

  function restart () {
    $.get(baseurl + 'backup/restart')
      .done(function (message) {
        Notify.message(message.result);
      })
      .fail(function (data) {
        data = JSON.parse(data.responseText);
        var notification = Notify.message(data.result.message, {
          sticky: true,
          buttons: {
            "Show output": function () {
              notification.remove(1);
              Notify.message(nl2br(data.result.debug), {
                sticky: true
              });
            }
          }
        });
      })
  }

  function backup () {

    var notification = Notify.message('<img src="/ninja/application/media/images/loading.gif" /> Creating new backup..', {
      sticky: true,
      removable: false
    });

    $.get(baseurl + 'backup/backup')
      .done(function (response) {
        var file = response.result;

        var first = $('#backups tbody tr:first');

        notification.remove(1);
        Notify.message("Backup  '" + file + "' was created!");

        $('#backups tbody').prepend(
          $('<tr>').append(
            $('<td>').append(
              $('<a class="view_backup" style="border: 0px; margin-right: 4px">')
                .attr('href', baseurl + 'backup/view/' + file)
                .html('<span class="icon-16 x16-backup-view"></span>'),
              $('<a class="restore_backup" style="border: 0px; margin-right: 4px">')
                .attr('href', baseurl + 'backup/restore/' + file)
                .html('<span class="icon-16 x16-backup-restore"></span>'),
              $('<a class="delete_backup" style="border: 0px; margin-right: 4px">')
                .attr('href', baseurl + 'backup/delete/' + file)
                .html('<span class="icon-16 x16-backup-delete"></span>')
            ),
            $('<td>').append(
              $('<a class="download_backup">')
                .attr('href', baseurl + 'backup/download/' + file)
                .text(file)
            )
          ).addClass(first.length && first.hasClass('odd') ? 'even' : 'odd')
        );

      })
      .fail(function (data) {
        notification.remove(1);
        data = JSON.parse(data.responseText);
        notification = Notify.message(data.result.message, {
          type: "error",
          sticky: true,
          buttons: {
            "Show output": function () {
              notification.remove(1);
              Notify.message(nl2br(data.result.debug), {sticky: true});
            }
          }
        });
      });

  }

  $('#verify_backup').live('click', function(){

    var link = $(this);

    $.get($(link).attr('href'))
      .done(function (data) {
        var notification = Notify.message(
        data.result + '. Do you really want to backup your current configuration?',
        {
          sticky: true,
          buttons: {
            "Yes": function () {
              notification.remove(1);
              backup();
            }
          }
        });
      })
      .fail(function (data) {
        data = JSON.parse(data.responseText);
        var notification = Notify.message(data.result.message, {
          type: "error",
          sticky: true,
          buttons: {
            "Show output": function () {
              notification.remove(1);
              Notify.message(nl2br(data.result.debug), {sticky: true});
            },
            "Backup anyway": backup
          }
        });
      });

    return false;

  });

  $('a.restore_backup').live('click', function(ev){

    var link = $(this);
    var notification = Notify.message('Do you really want to restore this backup?', {
      sticky: true,
      buttons: {
        "Yes": function () {
          notification.remove(1);
          $.get(link.attr('href'))
            .done(function (data) {
              notification = Notify.message(data.result + '. Your new configuration will not be used until the monitoring process is restarted', {
                sticky: true,
                buttons: {
                  "Restart now": function () {
                    notification.remove(1);
                    restart();
                  }
                }
              });
            })
            .fail(function (data) {
              data = JSON.parse(data.responseText);
              Notify.message(data.result.message, {
                type: "error",
                sticky: true,
                "Show output": function () {
                  notification.remove(1);
                  Notify.message(nl2br(data.result.debug), {sticky: true});
                }
              });
            });
        }
      }
    });

    return false;

  });

  $('a.delete_backup').live('click', function(){

    var link = $(this);
    var notification = Notify.message(
      'Do you really want to delete ' + link.closest('tr').find('.download_backup').text() + ' ?',
      {
        sticky: true,
        buttons: {
          "Yes": function () {
            $.get(link.attr('href'))
              .done(function (data) {
                notification.remove(1);
                Notify.message(data.result);
                link.parents('tr').remove();
              })
              .fail(function (data) {
                notification.remove(1);
                data = JSON.parse(data.responseText);
                Notify.message(data.result.message, {
                  type: "error"
                });
              })
          }
        }
      });

    return false;

  });

})();



/*******************
 * From src: modules/monitoring/src/js/extinfo.js
 *******************/
/**
 * When executing custom commands we do it over ajax and present the result in
 * a dialog (lightbox)
 */
$(document).on('click','a[data-custom-command]', function (e) {

	e.preventDefault();

	var command = $(this).text();
	var href = $(this).attr('href');

	var present = function (content)  {

		var lightbox = LightboxManager.create();
		var header = document.createElement('h1');
		header.textContent = 'Command result - ' + command;

		lightbox.show();
		lightbox.header(header);
		lightbox.content(content);
		lightbox.button("OK", function() {
			LightboxManager.remove_topmost();
		});

	};

	$.get(href)
		.done(function (data) {

			present($('<div />').append(
				$('<p class="output" />').html(data.output)
			).get(0));

		})
		.fail(function (data) {

			try {
				data = JSON.parse(data.responseText);
			} catch (e) {
				/* Possibly in the case of an unhandled exception */
				data = {output: "An unexpected error occured when attempting to execute the custom command"}
			}

			present($('<div />').append(
				$('<p class="alert error" />').append(
					$('<h2>').text('Command failed')
				),
				$('<p class="output" />').html(data.output)
			).get(0));

		});
});

$(document).on('click','div[data-setting-toggle-command]', function () {

	var toggler = $(this);
	var command = toggler.attr('data-setting-toggle-command');
	var query = toggler.attr('data-setting-toggle-query');
	var on = command.match(/^(disable_|stop_)/);

	/* Do nothing if the current toggle is waiting for response */
	if (toggler.hasClass('toggle-waiting'))
		return;

	toggler.addClass('toggle-waiting');

	query = decodeURIComponent(query);
	var url = _site_domain + _index_page;
	$.post(url + '/cmd/ajax_command', {
		'csrf_token': _csrf_token,
		'command': command,
		'query': query
	}).done(function () {
		if (on) {
			command = command.replace(/disable_/, 'enable_');
			command = command.replace(/stop_/, 'start_');
			toggler.attr('data-setting-toggle-state', 'off');
			toggler.attr('data-setting-toggle-command', command)
		} else {
			command = command.replace(/enable_/, 'disable_');
			command = command.replace(/start_/, 'stop_');
			toggler.attr('data-setting-toggle-state', 'on');
			toggler.attr('data-setting-toggle-command', command)
		}
	}).fail(function () {
		Notify.message("Failed to toggle setting.", {type: "error", sticky: true});
	}).complete(function () {
		toggler.removeClass('toggle-waiting');
	});


});

$(document).on('click', '.information-performance-raw-show', function () {
	var table = $(this).siblings('table');
	if (table.is(':hidden')) {
		$(this).find('.information-performance-raw-show-label').text('Hide raw data');
		$(this).siblings('table').show();
	} else {
		$(this).find('.information-performance-raw-show-label').text('Show raw data');
		$(this).siblings('table').hide();
	}
});



/*******************
 * From src: modules/monitoring/src/js/generated/ninja_manifest.js
 *******************/
// 
// NOTE!
// 
// This is an auto generated file. Changes to this file will be overwritten!
// 
if(typeof(ninja_manifest) === "undefined") {
ninja_manifest = {}
}
$.extend(true, ninja_manifest, {"autocomplete":{"contacts":[{"display_column":"name","query":"[contacts] name ~~ \"%s\""}],"hosts":[{"display_column":"name","query":"[hosts] name ~~ \"%s\""}],"services":[{"display_column":"description","query":"[services] description ~~ \"%s\""},{"display_column":"description","query":"[services] host.name ~~ \"%s\""}]},"lsfilter_extra_js":["modules\/monitoring\/views\/recurring_downtime\/js\/recurring_downtime.js"],"orm_command_doctags":{"comment_model":{"delete":{"name":"Delete comment","category":"Operations","icon":"delete-comment.delete","mayi_method":"delete.command","description":"Delete a comment.","view":"monitoring\/naemon_command"}},"downtime_model":{"delete":{"name":"Delete downtime","category":"Operations","icon":"delete-downtime","mayi_method":"delete.command.delete","description":"Delete\/cancel a scheduled downtime entry.","view":"monitoring\/naemon_command"}},"host_model":{"get_notes_url":{"name":"Notes","category":"Links","icon":"host-notes","mayi_method":"read.extinfo","description":"Follow the notes links","enabled_if":"notes_url","redirect":"1"},"get_action_url":{"name":"Actions","category":"Links","icon":"host-actions","mayi_method":"read.extinfo","description":"Follow the action link","enabled_if":"action_url","redirect":"1"},"check_now":{"name":"Check now","category":"Actions","icon":"re-schedule","mayi_method":"update.command.schedule","description":"Schedule the next check as soon as possible","view":"monitoring\/naemon_command"},"acknowledge_problem":{"name":"Acknowledge Problem","category":"Actions","icon":"acknowledged","params":{"comment":{"id":"0","type":"string","name":"Comment"},"sticky":{"id":"1","type":"bool","name":"Sticky","default":"1","description":"If you want acknowledgement to disable notifications until the host recovers, check this checkbox."},"notify":{"id":"2","type":"bool","name":"Notify","default":"1","description":"If you want an acknowledgement notification sent out to the appropriate contacts, check this checkbox."},"persistent":{"id":"3","type":"bool","name":"Persistent","default":"1","description":"If you would like the host comment to remain once the acknowledgement is removed, check this checkbox."}},"mayi_method":"update.command.acknowledge","description":"This command is used to acknowledge a host problem. When a host problem is acknowledged, future notifications about problems are temporarily disabled until the host changes from its current state. If you want acknowledgement to disable notifications until the host recovers, check the 'Sticky Acknowledgement' checkbox. Contacts for this host will receive a notification about the acknowledgement, so they are aware that someone is working on the problem.  Additionally, a comment will also be added to the host. Make sure to enter your name and fill in a brief description of what you are doing in the comment field. If you would like the host comment to remain once the acknowledgement is removed, check the 'Persistent Comment' checkbox.  If you do not want an acknowledgement notification sent out to the appropriate contacts, uncheck the 'Notify' checkbox.","enabled_if":"unacknowledged_problem","view":"monitoring\/naemon_command"},"remove_acknowledgement":{"name":"Remove acknowledgement","category":"Actions","icon":"acknowledged-not","mayi_method":"update.command.acknowledge","description":"This command is used to remove an acknowledgement for a host problem. Once the acknowledgement is removed, notifications may start being sent out about the host problem.","enabled_if":"acknowledged_problem","view":"monitoring\/naemon_command"},"add_comment":{"name":"Add a new comment","category":"Actions","icon":"add-comment","params":{"comment":{"id":"0","type":"string","name":"Comment"}},"mayi_method":"update.command.comment","description":"This command is used to add a comment for the specified host. If you work with other administrators, you may find it useful to share information about a host that is having problems if more than one of you may be working on it.","view":"monitoring\/naemon_command"},"enable_check":{"name":"Enable active checks","category":"Operations","icon":"enable","mayi_method":"update.command.enabled","description":"This command is used to enable active checks of this host.","enabled_if":"checks_disabled","view":"monitoring\/naemon_command"},"disable_check":{"name":"Disable active checks","category":"Operations","icon":"disable-active-checks","mayi_method":"update.command.enabled","description":"This command is used to temporarily prevent Nagios from actively checking the status of a host.  If Nagios needs to check the status of this host, it will assume that it is in the same state that it was in before checks were disabled.","enabled_if":"checks_enabled","view":"monitoring\/naemon_command"},"process_check_result":{"name":"Submit passive check result","category":"Actions","icon":"checks-passive","mayi_method":"update.command.passive","params":{"plugin_output":{"id":"0","type":"string","name":"Plugin output","description":"The status string reported as plugin output"},"status_code":{"id":"1","type":"select","name":"Status code","option":["Up","Down","Unreachable"]},"perf_data":{"id":"2","type":"string","name":"Perf data","description":"Performance data, formatted as monitoring-plugins defines"}},"description":"This command is used to submit a passive check result for a host.","enabled_if":"accept_passive_checks","view":"monitoring\/naemon_command"},"schedule_check":{"name":"Re-schedule next host check","category":"Actions","icon":"re-schedule","mayi_method":"update.command.schedule","params":{"check_time":{"id":"0","type":"time","name":"Check time","default":"now","description":"Enter a check time in the format: YYYY-MM-DD hh:mm::ss"},"forced":{"id":"1","type":"bool","name":"Force check","default":"1","description":"If you want Naemon to force a check of the host regardless of both what time the scheduled check occurs and whether or not checks are enabled for the host, check this checkbox."}},"description":"This command is used to schedule the next check of a host. Naemon will re-queue the host to be checked at the time you specify. If you select the <i>force check<\/i> option, Naemon will force a check of the host regardless of both what time the scheduled check occurs and whether or not checks are enabled for the host.","enabled_if":"checks_enabled","view":"monitoring\/naemon_command"},"schedule_downtime":{"name":"Schedule downtime","category":"Actions","icon":"scheduled-downtime","mayi_method":"update.command.downtime","params":{"start_time":{"id":"0","type":"time","name":"Start time","default":"now","description":"Start time in the format: YYYY-MM-DD hh:mm:ss"},"end_time":{"id":"1","type":"time","name":"End time","default":"now + 2hours","description":"End time in the format: YYYY-MM-DD hh:mm:ss"},"flexible":{"id":"2","type":"bool","name":"Flexible","description":"Flexible downtime starts when the host goes down or becomes unreachable (sometime between the start and end times you specified) and lasts as long as the duration of time you enter."},"duration":{"id":"3","type":"duration","name":"Duration","default":"2.0","description":"Only for flexible downtimes. Number of hours from first problem the scheduled downtime should progress"},"trigger_id":{"id":"4","type":"object","query":"[downtimes] all","name":"Triggering downtime","description":"Only for flexible downtimes. Which downtime that should trigger this downtime"},"propagation":{"id":"5","type":"select","name":"Propagate to children","option":["No propagation","Propagate to child hosts","Propagate as triggered downtime to child hosts"],"description":"Also add this downtime to children hosts. If selecting propagation, this downtime, with its parameters, will be added to all children hosts automatically. If selected that propagation is triggered, the downtime on children hosts is registered as flexible, triggered by the selected host."},"comment":{"id":"6","type":"string","name":"Comment"}},"description":"This command is used to schedule downtime for a host. During the specified downtime, Naemon will not send notifications out about the host. When the scheduled downtime expires, Naemon will send out notifications for this host as it normally would. Scheduled downtimes are preserved across program shutdowns and restarts.","view":"monitoring\/naemon_command"},"cancel_all_downtimes":{"name":"Cancel all downtimes","category":"Actions","icon":"delete-downtime","mayi_method":"delete.command.delete","description":"Cancel all scheduled downtime entries for the host.","view":"monitoring\/naemon_command"},"send_notification":{"name":"Send custom notification","category":"Actions","icon":"notify-send","mayi_method":"update.command.send_notification","params":{"comment":{"id":"0","type":"string","name":"Comment"},"broadcast":{"id":"1","type":"bool","name":"Broadcast","default":"0"},"force_notification":{"id":"2","type":"bool","name":"Force notification","default":"0"}},"description":"This command is used to send a custom notification about the specified host. Useful in emergencies when you need to notify admins of an issue regarding a monitored system or service. Custom notifications normally follow the regular notification logic in Naemon. Selecting the <i>Forced<\/i> option will force the notification to be sent out, regardless of the time restrictions, whether or not notifications are enabled, etc.  Selecting the <i>Broadcast<\/i> option causes the notification to be sent out to all normal (non-escalated) and escalated contacts. These options allow you to override the normal notification logic if you need to get an important message out.","view":"monitoring\/naemon_command"},"enable_service_notifications":{"name":"Enable notifications for all services","category":"Service Operations","icon":"notify-send","mayi_method":"update.command.notification","description":"This command is used to enable notifications for all services on the specified host.  Notifications will only be sent out for the service state types you defined in your service definition.  This <i>does not<\/i> enable notifications for the host unless you check the 'Enable for host too' option.","view":"monitoring\/naemon_command"},"disable_service_notifications":{"name":"Disable notifications for all services","category":"Service Operations","icon":"notify-disabled","mayi_method":"update.command.notification","description":"This command is used to prevent notifications from being sent out for all services on the specified host.  You will have to re-enable notifications for all services associated with this host before any alerts can be sent out in the future.  This <i>does not<\/i> prevent notifications from being sent out about the host unless you check the 'Disable for host too' option.","view":"monitoring\/naemon_command"},"enable_service_checks":{"name":"Enable checks of all services","category":"Service Operations","icon":"enable","mayi_method":"update.command.enabled","description":"This command is used to enable active checks of all services associated with the specified host.  This <i>does not<\/i> enable checks of the host unless you check the 'Enable for host too' option.","view":"monitoring\/naemon_command"},"disable_service_checks":{"name":"Disable checks of all services","category":"Service Operations","icon":"disable-active-checks","mayi_method":"update.command.enabled","description":"This command is used to disable active checks of all services associated with the specified host.  When a service is disabled Naemon will not monitor the service.  Doing this will prevent any notifications being sent out for the specified service while it is disabled.  In order to have Nagios check the service in the future you will have to re-enable the service. Note that disabling service checks may not necessarily prevent notifications from being sent out about the host which those services are associated with.  This <i>does not<\/i> disable checks of the host unless you check the 'Disable for host too' option.","view":"monitoring\/naemon_command"},"locate_on_nagvis_map":{"name":"Locate host on map","category":"Links","icon":"locate-host-on-map","mayi_method":"read.nagvis","description":"Find the host on a nagvis automap.","redirect":"1"},"notifications":{"name":"Notifications","category":"Links","icon":"notification","mayi_method":"read","description":"Show host notifications.","redirect":"1"},"graphs":{"name":"Graphs","category":"Links","icon":"pnp","mayi_method":"read","description":"Show host graphs.","redirect":"1"},"schedule_service_checks":{"name":"Schedule a check of all services","category":"Service Operations","icon":"re-schedule","mayi_method":"update.command.schedule","params":{"check_time":{"id":"0","type":"time","name":"Check time","default":"now","description":"Enter a check time in the format: YYYY-MM-DD hh:mm::ss"},"forced":{"id":"1","type":"bool","name":"Forced","default":"1","description":"If you want Naemon to force a check of the services regardless of both what time the scheduled check occurs and whether or not checks are enabled for the services, check this checkbox."}},"description":"This command is used to scheduled the next check of all services on the specified host. If you select the <i>force check<\/i> option, Naemon will force a check of all services on the host regardless of both what time the scheduled checks occur and whether or not checks are enabled for those services.","view":"monitoring\/naemon_command"},"stop_obsessing":{"name":"Stop obsessing over this host","category":"Operations","icon":"shield-disabled","mayi_method":"update.command.obsess","description":"Disables processing of host checks via the OCHP command for the specified host.","enabled_if":"obsess","view":"monitoring\/naemon_command"},"start_obsessing":{"name":"Start obsessing over this host","category":"Operations","icon":"shield-enabled","mayi_method":"update.command.obsess","description":"Disables processing of host checks via the OCHP command for the specified host.","enabled_if":"!obsess","view":"monitoring\/naemon_command"},"stop_accept_passive_checks":{"name":"Stop accepting passive checks","category":"Operations","icon":"shield-disabled","mayi_method":"update.command.enabled","description":"Stop accepting new passive host check results","enabled_if":"accept_passive_checks","view":"monitoring\/naemon_command"},"start_accept_passive_checks":{"name":"Start accepting passive checks for","category":"Operations","icon":"shield-enabled","mayi_method":"update.command.enabled","description":"Start accepting new passive host check results","enabled_if":"!accept_passive_checks","view":"monitoring\/naemon_command"},"stop_notifications":{"name":"Disable notifications","category":"Operations","icon":"notify-disabled","mayi_method":"update.command.notification","description":"Disable notifications from this host. No contacts will be contacted if this host are having trouble.","enabled_if":"notifications_enabled","view":"monitoring\/naemon_command"},"start_notifications":{"name":"Enable notifications","category":"Operations","icon":"notify","mayi_method":"update.command.notification","description":"Enable notifications from this host. Contacts for this host will be contacted if this host are having trouble, if there are no other reason for notifications to be prevented, like scheduled downtime or reachabilitiy.","enabled_if":"!notifications_enabled","view":"monitoring\/naemon_command"},"stop_event_handler":{"name":"Disable event handler","category":"Operations","icon":"shield-disabled","mayi_method":"update.command.event_handler","description":"Disable execution of the custom event handler for this host.","enabled_if":"event_handler_enabled","view":"monitoring\/naemon_command"},"start_event_handler":{"name":"Enable event handler","category":"Operations","icon":"shield-enabled","mayi_method":"update.command.event_handler","description":"Enable execution of the custom event handler for this host.","enabled_if":"!event_handler_enabled","view":"monitoring\/naemon_command"},"stop_flap_detection":{"name":"Disable flap detection","category":"Operations","icon":"shield-disabled","mayi_method":"update.command.flap_detection","description":"Disable analysis of this host is flapping. If no flap detection analysis is enabled, the host will trigger a problem and recovery notification every time the host goes up or down, not only just a \"flapping\" notification when it starts flapping,","enabled_if":"flap_detection_enabled","view":"monitoring\/naemon_command"},"start_flap_detection":{"name":"Enable flap detection","category":"Operations","icon":"shield-enabled","mayi_method":"update.command.flap_detection","description":"Enable analysis of this host is flapping. If flap detection analysis is enabled, the host will trigger flapping notification when the host starts to rapidly change between states, instead of sending lot of notifications for every state change.","enabled_if":"!flap_detection_enabled","view":"monitoring\/naemon_command"},"get_config_url":{"name":"Configure","category":"Configuration","icon":"nacoma","mayi_method":"update.command.configure","description":"Configure this host","enabled_if":"config_allowed","redirect":"1"},"delete":{"name":"Delete","category":"Configuration","icon":"delete","mayi_method":"delete.command.delete","description":"Delete the host in Nacoma, and queue it in the changelog. The changes still needs to be published in nacoma before the host is removed from the running config","view":"monitoring\/nacoma_command"}},"hostgroup_model":{"get_config_url":{"name":"Configure","category":"Configuration","icon":"nacoma","mayi_method":"update.command.configure","description":"Configure this hostgroup.","redirect":"1"},"disable_host_checks":{"name":"Disable active host checks","category":"Host Operations","icon":"disable-active-checks","mayi_method":"update.command.enabled","description":"Disables active checks for all hosts in this hostgroup.","view":"monitoring\/naemon_command"},"disable_host_notifications":{"name":"Disable host notifications","category":"Host Operations","icon":"notify-disabled","mayi_method":"update.command.notification","description":"Disable notifications for all hosts in this hostgroup.","view":"monitoring\/naemon_command"},"disable_service_checks":{"name":"Disable active service checks","category":"Service Operations","icon":"disable-active-checks","mayi_method":"update.command.enabled","description":"Disables active checks for all services associated with hosts in this hostgroup.","view":"monitoring\/naemon_command"},"disable_service_notifications":{"name":"Disable service notifications","category":"Service Operations","icon":"notify-disabled","mayi_method":"update.command.notification","description":"This command is used to prevent notifications from being sent out for all services in the specified hostgroup. You will have to re-enable notifications for all services in this hostgroup before any alerts can be sent out in the future. This <i>does not<\/i> prevent notifications from being sent out about the hosts in this hostgroup unless you check the 'Disable for hosts too' option.","view":"monitoring\/naemon_command"},"enable_host_checks":{"name":"Enable active host checks","category":"Host Operations","icon":"enable","mayi_method":"update.command.enabled","description":"Enables active checks for all hosts in this hostgroup.","view":"monitoring\/naemon_command"},"enable_host_notifications":{"name":"Enable host notifications","category":"Host Operations","icon":"notify","mayi_method":"update.command.notification","description":"Enable notifications for all hosts in this hostgroup.","view":"monitoring\/naemon_command"},"enable_service_checks":{"name":"Enable active service checks","category":"Service Operations","icon":"enable","mayi_method":"update.command.enabled","description":"This command is used to enable active checks of all services in the specified hostgroup. This <i>does not<\/i> enable active checks of the hosts in the hostgroup unless you check the 'Enable for hosts too' option.","view":"monitoring\/naemon_command"},"enable_service_notifications":{"name":"Enable service notifications","category":"Service Operations","icon":"notify-send","mayi_method":"update.command.notification","description":"This command is used to enable notifications for all services in the specified hostgroup. Notifications will only be sent out for the service state types you defined in your service definitions. This <i>does not<\/i> enable notifications for the hosts in this hostgroup unless you check the 'Enable for hosts too' option."},"schedule_host_downtime":{"name":"Schedule host downtime","category":"Actions","icon":"scheduled-downtime","mayi_method":"update.command.downtime","params":{"start_time":{"id":"0","type":"time","name":"Start time","default":"now","description":"Start time in the format: YYYY-MM-DD hh:mm:ss"},"end_time":{"id":"1","type":"time","name":"End time","default":"now + 2hours","description":"End time in the format: YYYY-MM-DD hh:mm:ss"},"flexible":{"id":"2","type":"bool","name":"Flexible","description":"Flexible downtime starts when the host goes down or becomes unreachable (sometime between the start and end times you specified) and lasts as long as the duration of time you enter."},"duration":{"id":"3","type":"duration","name":"Duration","default":"2.0","description":"Only for flexible downtimes. Number of hours from first problem the scheduled downtime should progress"},"trigger_id":{"id":"4","type":"object","query":"[downtimes] all","name":"Triggering downtime","description":"Only for flexible downtimes. Which downtime that should trigger this downtime"},"propagation":{"id":"5","type":"select","name":"Propagate to children","option":["No propagation","Propagate to child hosts","Propagate as triggered downtime to child hosts"],"description":"Also add this downtime to children hosts. If selecting propagation, this downtime, with its parameters, will be added to all children hosts automatically. If selected that propagation is triggered, the downtime on children hosts is registered as flexible, triggered by the selected host."},"comment":{"id":"6","type":"string","name":"Comment"}},"description":"This command is used to schedule downtime for all hosts in a hostgroup. During the specified downtime, Naemon will not send notifications out about the hosts. When the scheduled downtime expires, Naemon will send out notifications for the hosts as it normally would. Scheduled downtimes are preserved across program shutdowns and restarts.","view":"monitoring\/naemon_command"},"schedule_service_downtime":{"name":"Schedule service downtime","category":"Actions","icon":"scheduled-downtime","mayi_method":"update.command.downtime","params":{"start_time":{"id":"0","type":"time","name":"Start time","default":"now","description":"Start time in the format: YYYY-MM-DD hh:mm:ss"},"end_time":{"id":"1","type":"time","name":"End time","default":"now + 2hours","description":"End time in the format: YYYY-MM-DD hh:mm:ss"},"flexible":{"id":"2","type":"bool","name":"Flexible","description":"Flexible downtime starts when the service get a problem state (sometime between the start and end times you specified) and lasts as long as the duration of time you enter."},"duration":{"id":"3","type":"duration","name":"Duration","default":"2.0","description":"Only for flexible downtimes. Number of hours from first problem the scheduled downtime should progress"},"trigger_id":{"id":"4","type":"object","query":"[downtimes] all","name":"Triggering downtime","description":"Only for flexible downtimes. Which downtime that should trigger this downtime"},"comment":{"id":"5","type":"string","name":"Comment"}},"description":"This command is used to schedule downtime for all services in a hostgroup. During the specified downtime, Naemon will not send notifications out about the services. When the scheduled downtime expires, Naemon will send out notifications for the services as it normally would. Scheduled downtimes are preserved across program shutdowns and restarts.","view":"monitoring\/naemon_command"}},"service_model":{"get_notes_url":{"name":"Notes","category":"Links","icon":"host-notes","mayi_method":"read.extinfo","description":"Follow the notes links","enabled_if":"notes_url","redirect":"1"},"get_action_url":{"name":"Actions","category":"Links","icon":"host-actions","mayi_method":"read.extinfo","description":"Follow the action link","enabled_if":"action_url","redirect":"1"},"notifications":{"name":"Notifications","category":"Links","icon":"notification","mayi_method":"read","description":"Show host notifications.","redirect":"1"},"graphs":{"name":"Graphs","category":"Links","icon":"pnp","mayi_method":"read","description":"Show host graphs.","redirect":"1"},"acknowledge_problem":{"name":"Acknowledge Problem","category":"Actions","icon":"acknowledged","params":{"comment":{"id":"0","type":"string","name":"Comment"},"sticky":{"id":"1","type":"bool","name":"Sticky","default":"1","description":"If you want acknowledgement to disable notifications until the service recovers, check this checkbox."},"notify":{"id":"2","type":"bool","name":"Notify","default":"1","description":"If you want an acknowledgement notification sent out to the appropriate contacts, check this checkbox."},"persistent":{"id":"3","type":"bool","name":"Persistent","default":"1","description":"If you would like the service comment to remain once the acknowledgement is removed, check this checkbox."}},"mayi_method":"update.command.acknowledge","description":"This command is used to acknowledge a host problem. When a host problem is acknowledged, future notifications about problems are temporarily disabled until the host changes from its current state. If you want acknowledgement to disable notifications until the host recovers, check the 'Sticky Acknowledgement' checkbox. Contacts for this host will receive a notification about the acknowledgement, so they are aware that someone is working on the problem.  Additionally, a comment will also be added to the host. Make sure to enter your name and fill in a brief description of what you are doing in the comment field. If you would like the host comment to remain once the acknowledgement is removed, check the 'Persistent Comment' checkbox.  If you do not want an acknowledgement notification sent out to the appropriate contacts, uncheck the 'Notify' checkbox.","enabled_if":"unacknowledged_problem","view":"monitoring\/naemon_command"},"remove_acknowledgement":{"name":"Remove acknowledgement","category":"Actions","icon":"acknowledged-not","mayi_method":"update.command.acknowledge","description":"This command is used to remove an acknowledgement for a host problem. Once the acknowledgement is removed, notifications may start being sent out about the host problem.","enabled_if":"acknowledged_problem","view":"monitoring\/naemon_command"},"check_now":{"name":"Check now","category":"Actions","icon":"re-schedule","mayi_method":"update.command.schedule","description":"Schedule the next check as soon as possible","view":"monitoring\/naemon_command"},"add_comment":{"name":"Add a new comment","category":"Actions","icon":"add-comment","mayi_method":"update.command.comment","params":{"comment":{"id":"0","type":"string","name":"Comment"}},"description":"This command is used to add a comment for the specified service. If you work with other administrators, you may find it useful to share information about a host or service that is having problems if more than one of you may be working on it.","view":"monitoring\/naemon_command"},"enable_check":{"name":"Enable active checks","category":"Operations","icon":"enable","mayi_method":"update.command.enabled","description":"This command is used to enable active checks of this service.","enabled_if":"checks_disabled","view":"monitoring\/naemon_command"},"disable_check":{"name":"Disable active checks","category":"Operations","icon":"disable-active-checks","mayi_method":"update.command.enabled","description":"This command is used to temporarily prevent Nagios from actively checking the status of a service.  If Nagios needs to check the status of this service, it will assume that it is in the same state that it was  in before checks were disabled.","enabled_if":"checks_enabled","view":"monitoring\/naemon_command"},"process_check_result":{"name":"Submit passive check result","category":"Actions","icon":"checks-passive","mayi_method":"update.command.passive","params":{"plugin_output":{"id":"0","type":"string","name":"Plugin output","description":"The status string reported as plugin output"},"status_code":{"id":"1","type":"select","name":"Status code","option":["Ok","Warning","Critical","Unknown"]},"perf_data":{"id":"2","type":"string","name":"Perf data","description":"Performance data, formatted as monitoring-plugins defines"}},"description":"This command is used to submit a passive check result for a service. It is particularly useful for resetting security-related services to OK states once they have been dealt with.","enabled_if":"accept_passive_checks","view":"monitoring\/naemon_command"},"schedule_check":{"name":"Re-schedule next service check","category":"Actions","icon":"re-schedule","mayi_method":"update.command.schedule","params":{"check_time":{"id":"0","type":"time","name":"Check time","default":"now","description":"Enter a check time in the format: YYYY-MM-DD hh:mm::ss"},"forced":{"id":"1","type":"bool","name":"Force check","default":"1","description":"If you want Naemon to force a check of the service regardless of both what time the scheduled check occurs and whether or not checks are enabled for the service, check this checkbox."}},"description":"This command is used to schedule the next check of a service. Naemon will re-queue the service to be checked at the time you specify. If you select the <i>force check<\/i> option, Naemon will force a check of the service regardless of both what time the scheduled check occurs and whether or not checks are enabled for the service.","enabled_if":"checks_enabled","view":"monitoring\/naemon_command"},"schedule_downtime":{"name":"Schedule downtime","category":"Actions","icon":"scheduled-downtime","mayi_method":"update.command.downtime","params":{"start_time":{"id":"0","type":"time","name":"Start time","default":"now","description":"Start time in the format: YYYY-MM-DD hh:mm:ss"},"end_time":{"id":"1","type":"time","name":"End time","default":"now + 2hours","description":"End time in the format: YYYY-MM-DD hh:mm:ss"},"flexible":{"id":"2","type":"bool","name":"Flexible","description":"Flexible downtime starts when the service gets a problem state (sometime between the start and end times you specified) and lasts as long as the duration of time you enter."},"duration":{"id":"3","type":"duration","name":"Duration","default":"2.0","description":"Only for flexible downtimes. Number of hours from first problem the scheduled downtime should progress"},"trigger_id":{"id":"4","type":"object","query":"[downtimes] all","name":"Triggering downtime","description":"Only for flexible downtimes. Which downtime that should trigger this downtime"},"comment":{"id":"5","type":"string","name":"Comment"}},"description":"This command is used to schedule downtime for a service. During the specified downtime, Naemon will not send notifications out about the service. When the scheduled downtime expires, Naemon will send out notifications for this service as it normally would. Scheduled downtimes are preserved across program shutdowns and restarts.","view":"monitoring\/naemon_command"},"cancel_all_downtimes":{"name":"Cancel all downtimes","category":"Actions","icon":"delete-downtime","mayi_method":"delete.command.delete","description":"Cancel all scheduled downtime entries for the service.","view":"monitoring\/naemon_command"},"send_notification":{"name":"Send custom notification","category":"Actions","icon":"notify-send","mayi_method":"update.command.send_notification","params":{"comment":{"id":"0","type":"string","name":"Comment"}},"description":"This command is used to send a custom notification about the specified service. Useful in emergencies when you need to notify admins of an issue regarding a monitored system or service. Custom notifications normally follow the regular notification logic in Naemon. Selecting the <i>Forced<\/i> option will force the notification to be sent out, regardless of the time restrictions, whether or not notifications are enabled, etc. Selecting the <i>Broadcast<\/i> option causes the notification to be sent out to all normal (non-escalated) and escalated contacts. These options allow you to override the normal notification logic if you need to get an important message out.","view":"monitoring\/naemon_command"},"stop_obsessing":{"name":"Stop obsessing over this service","category":"Operations","icon":"shield-disabled","mayi_method":"update.command.obsess","description":"Disables processing of service checks via the OCSP command for the specified service.","enabled_if":"obsess","view":"monitoring\/naemon_command"},"start_obsessing":{"name":"Start obsessing over this service","category":"Operations","icon":"shield-enabled","mayi_method":"update.command.obsess","description":"Disables processing of service checks via the OCSP command for the specified service.","enabled_if":"!obsess","view":"monitoring\/naemon_command"},"stop_accept_passive_checks":{"name":"Stop accepting passive checks","category":"Operations","icon":"shield-disabled","mayi_method":"update.command.enabled","description":"Stop accepting new passive service check results","enabled_if":"accept_passive_checks","view":"monitoring\/naemon_command"},"start_accept_passive_checks":{"name":"Start accepting passive checks","category":"Operations","icon":"shield-enabled","mayi_method":"update.command.enabled","description":"Start accepting new passive service check results","enabled_if":"!accept_passive_checks","view":"monitoring\/naemon_command"},"stop_notifications":{"name":"Disable notifications","category":"Operations","icon":"notify-disabled","mayi_method":"update.command.notification","description":"Disable notifications from this service. No contacts will be contacted if this service are having trouble.","enabled_if":"notifications_enabled","view":"monitoring\/naemon_command"},"start_notifications":{"name":"Enable notifications","category":"Operations","icon":"notify","mayi_method":"update.command.notification","description":"Enable notifications from this service. Contacts for this host will be contacted if this service are having trouble, if there are no other reason for notifications to be prevented, like scheduled downtime or service dependencies.","enabled_if":"!notifications_enabled","view":"monitoring\/naemon_command"},"stop_event_handler":{"name":"Disable event handler","category":"Operations","icon":"shield-disabled","mayi_method":"update.command.event_handler","description":"Disable execution of the custom event handler for this service.","enabled_if":"event_handler_enabled","view":"monitoring\/naemon_command"},"start_event_handler":{"name":"Enable event handler","category":"Operations","icon":"shield-enabled","mayi_method":"update.command.event_handler","description":"Enable execution of the custom event handler for this service.","enabled_if":"!event_handler_enabled","view":"monitoring\/naemon_command"},"stop_flap_detection":{"name":"Disable flap detection","category":"Operations","icon":"shield-disabled","mayi_method":"update.command.flap_detection","description":"Disable analysis of this service is flapping. If no flap detection analysis is enabled, the service will trigger a problem and recovery notification every time the service goes ok or problem, not only just a \"flapping\" notification when it starts flapping,","enabled_if":"flap_detection_enabled","view":"monitoring\/naemon_command"},"start_flap_detection":{"name":"Enable flap detection","category":"Operations","icon":"shield-enabled","mayi_method":"update.command.flap_detection","description":"Enable analysis of this service is flapping. If flap detection analysis is enabled, the service will trigger flapping notification when the service starts to rapidly change between states, instead of sending lot of notifications for every state change.","enabled_if":"!flap_detection_enabled","view":"monitoring\/naemon_command"},"get_config_url":{"name":"Configure","category":"Configuration","icon":"nacoma","mayi_method":"update.command.configure","description":"Configure this service","enabled_if":"config_allowed","redirect":"1"},"delete":{"name":"Delete","category":"Configuration","icon":"delete","mayi_method":"delete.command.delete","params":{"forced":{"id":"0","type":"bool","name":"Remove hostgroup services","description":"Allow removal of services even if they originates from a hostgroup. Removing those services will also remove them from all other hosts in the hostgroup. Verify the output in the nacoma submit changes page before submitting."}},"description":"Delete the host in Nacoma, and queue it in the changelog. The changes still needs to be published in nacoma before the host is removed from the running config","view":"monitoring\/nacoma_command"}},"servicegroup_model":{"get_config_url":{"name":"Configure","category":"Configuration","icon":"nacoma","mayi_method":"update.command.configure","description":"Configure this servicegroup.","redirect":"1"},"disable_host_checks":{"name":"Disable active host checks","category":"Host Operations","icon":"disable-active-checks","mayi_method":"update.command.enabled","description":"Disables active checks for all hosts in this servicegroup.","view":"monitoring\/naemon_command"},"disable_host_notifications":{"name":"Disable host notifications","category":"Host Operations","icon":"notify-disabled","mayi_method":"update.command.notification","description":"Disable notifications for all hosts in this servicegroup.","view":"monitoring\/naemon_command"},"disable_service_checks":{"name":"Disable active service checks","category":"Service Operations","icon":"disable-active-checks","mayi_method":"update.command.enabled","description":"This command is used to disable active checks of all services in the specified servicegroup. This <i>does not<\/i> disable checks of the hosts in the servicegroup unless you check the 'Disable for hosts too' option.","view":"monitoring\/naemon_command"},"disable_service_notifications":{"name":"Disable service notifications","category":"Service Operations","icon":"notify-disabled","mayi_method":"update.command.notification","description":"This command is used to prevent notifications from being sent out for all services in the specified servicegroup. You will have to re-enable notifications for all services in this servicegroup before any alerts can be sent out in the future. This <i>does not<\/i> prevent notifications from being sent out about the hosts in this servicegroup unless you check the 'Disable for hosts too' option.","view":"monitoring\/naemon_command"},"enable_host_checks":{"name":"Enable active host checks","category":"Host Operations","icon":"enable","mayi_method":"update.command.enabled","description":"Enables active checks for all hosts in this servicegroup.","view":"monitoring\/naemon_command"},"enable_host_notifications":{"name":"Enable host notifications","category":"Host Operations","icon":"notify","mayi_method":"update.command.notification","description":"Enable notifications for all hosts in this servicegroup.","view":"monitoring\/naemon_command"},"enable_service_checks":{"name":"Enable active service checks","category":"Service Operations","icon":"enable","mayi_method":"update.command.enabled","description":"This command is used to enable active checks of all services in the specified servicegroup. This <i>does not<\/i> enable active checks of the hosts in the servicegroup unless you check the 'Enable for hosts too' option.","view":"monitoring\/naemon_command"},"enable_service_notifications":{"name":"Enable service notifications","category":"Service Operations","icon":"notify-send","mayi_method":"update.command.notification","description":"This command is used to enable notifications for all services in the specified servicegroup. Notifications will only be sent out for the service state types you defined in your service definitions. This <i>does not<\/i> enable notifications for the hosts in this servicegroup unless you check the 'Enable for hosts too' option.","view":"monitoring\/naemon_command"},"schedule_host_downtime":{"name":"Schedule host downtime","category":"Actions","icon":"scheduled-downtime","mayi_method":"update.command.downtime","params":{"start_time":{"id":"0","type":"time","name":"Start time","default":"now","description":"Start time in the format: YYYY-MM-DD hh:mm:ss"},"end_time":{"id":"1","type":"time","name":"End time","default":"now + 2hours","description":"End time in the format: YYYY-MM-DD hh:mm:ss"},"flexible":{"id":"2","type":"bool","name":"Flexible","description":"Flexible downtime starts when the host goes down or becomes unreachable (sometime between the start and end times you specified) and lasts as long as the duration of time you enter."},"duration":{"id":"3","type":"duration","name":"Duration","default":"2.0","description":"Only for flexible downtimes. Number of hours from first problem the scheduled downtime should progress"},"trigger_id":{"id":"4","type":"object","query":"[downtimes] all","name":"Triggering downtime","description":"Only for flexible downtimes. Which downtime that should trigger this downtime"},"propagation":{"id":"5","type":"select","name":"Propagate to children","option":["No propagation","Propagate to child hosts","Propagate as triggered downtime to child hosts"],"description":"Also add this downtime to children hosts. If selecting propagation, this downtime, with its parameters, will be added to all children hosts automatically. If selected that propagation is triggered, the downtime on children hosts is registered as flexible, triggered by the selected host."},"comment":{"id":"6","type":"string","name":"Comment"}},"description":"This command is used to schedule downtime for all hosts in a servicegroup. During the specified downtime, Naemon will not send notifications out about the hosts. When the scheduled downtime expires, Naemon will send out notifications for the hosts as it normally would. Scheduled downtimes are preserved across program shutdowns and restarts.","view":"monitoring\/naemon_command"},"schedule_service_downtime":{"name":"Schedule service downtime","category":"Actions","icon":"scheduled-downtime","mayi_method":"update.command.downtime","params":{"start_time":{"id":"0","type":"time","name":"Start time","default":"now","description":"Start time in the format: YYYY-MM-DD hh:mm:ss"},"end_time":{"id":"1","type":"time","name":"End time","default":"now + 2hours","description":"End time in the format: YYYY-MM-DD hh:mm:ss"},"flexible":{"id":"2","type":"bool","name":"Flexible","description":"Flexible downtime starts when the service get a problem state (sometime between the start and end times you specified) and lasts as long as the duration of time you enter."},"duration":{"id":"3","type":"duration","name":"Duration","default":"2.0","description":"Only for flexible downtimes. Number of hours from first problem the scheduled downtime should progress"},"trigger_id":{"id":"4","type":"object","query":"[downtimes] all","name":"Triggering downtime","description":"Only for flexible downtimes. Which downtime that should trigger this downtime"},"comment":{"id":"5","type":"string","name":"Comment"}},"description":"This command is used to schedule downtime for all services in a servicegroup. During the specified downtime, Naemon will not send notifications out about the services. When the scheduled downtime expires, Naemon will send out notifications for the services as it normally would. Scheduled downtimes are preserved across program shutdowns and restarts.","view":"monitoring\/naemon_command"}},"status_model":{"restart_process":{"name":"Restart the Naemon process","category":"Process","icon":"command","mayi_method":"update.command.restart_process","view":"monitoring\/naemon_command"},"shutdown_process":{"name":"Shut down the Naemon process","category":"Process","icon":"command","mayi_method":"update.command.shutdown_process","view":"monitoring\/naemon_command"},"disable_notifications":{"name":"Disable notifications","category":"Operations","icon":"disabled","mayi_method":"update.command.notification","view":"monitoring\/naemon_command","enabled_if":"enable_notifications"},"enable_notifications":{"name":"Enable notifications","category":"Operations","icon":"enabled","mayi_method":"update.command.notification","view":"monitoring\/naemon_command","enabled_if":"!enable_notifications"},"disable_service_checks":{"name":"Stop executing service checks","category":"Service operations","icon":"disabled","mayi_method":"update.command.enabled","view":"monitoring\/naemon_command","enabled_if":"execute_service_checks"},"enable_service_checks":{"name":"Start executing service checks","category":"Service operations","icon":"enabled","mayi_method":"update.command.enabled","view":"monitoring\/naemon_command","enabled_if":"!execute_service_checks"},"disable_service_passive_checks":{"name":"Stop accepting passive service checks","category":"Service operations","icon":"disabled","mayi_method":"update.command.enabled","view":"monitoring\/naemon_command","enabled_if":"accept_passive_service_checks"},"enable_service_passive_checks":{"name":"Start accepting passive service checks","category":"Service operations","icon":"enabled","mayi_method":"update.command.enabled","view":"monitoring\/naemon_command","enabled_if":"!accept_passive_service_checks"},"disable_host_checks":{"name":"Stop executing host checks","category":"Host operations","icon":"disabled","mayi_method":"update.command.enabled","view":"monitoring\/naemon_command","enabled_if":"execute_host_checks"},"enable_host_checks":{"name":"Start executing host checks","category":"Host operations","icon":"enabled","mayi_method":"update.command.enabled","view":"monitoring\/naemon_command","enabled_if":"!execute_host_checks"},"disable_host_passive_checks":{"name":"Stop accepting passive host checks","category":"Host operations","icon":"disabled","mayi_method":"update.command.enabled","view":"monitoring\/naemon_command","enabled_if":"accept_passive_host_checks"},"enable_host_passive_checks":{"name":"Start accepting passive host checks","category":"Host operations","icon":"enabled","mayi_method":"update.command.enabled","view":"monitoring\/naemon_command","enabled_if":"!accept_passive_host_checks"},"disable_event_handlers":{"name":"Disable event handlers","category":"Operations","icon":"disabled","mayi_method":"update.command.event_handler","view":"monitoring\/naemon_command","enabled_if":"enable_event_handlers"},"enable_event_handlers":{"name":"Enable event handlers","category":"Operations","icon":"enabled","mayi_method":"update.command.event_handler","view":"monitoring\/naemon_command","enabled_if":"!enable_event_handlers"},"stop_obsessing_over_services":{"name":"Stop obsessing over services","category":"Service operations","icon":"disabled","mayi_method":"update.command.obsess","view":"monitoring\/naemon_command","enabled_if":"obsess_over_services"},"start_obsessing_over_services":{"name":"Start obsessing over services","category":"Service operations","icon":"enabled","mayi_method":"update.command.obsess","view":"monitoring\/naemon_command","enabled_if":"!obsess_over_services"},"stop_obsessing_over_hosts":{"name":"Stop obsessing over hosts","category":"Host operations","icon":"disabled","mayi_method":"update.command.obsess","view":"monitoring\/naemon_command","enabled_if":"obsess_over_hosts"},"start_obsessing_over_hosts":{"name":"Start obsessing over hosts","category":"Host operations","icon":"enabled","mayi_method":"update.command.obsess","view":"monitoring\/naemon_command","enabled_if":"!obsess_over_hosts"},"stop_flap_detection":{"name":"Disable flap detection","category":"Operations","icon":"disabled","mayi_method":"update.command.flap_detection","view":"monitoring\/naemon_command","enabled_if":"enable_flap_detection"},"start_flap_detection":{"name":"Enable flap detection","category":"Operations","icon":"enabled","mayi_method":"update.command.flap_detection","view":"monitoring\/naemon_command","enabled_if":"!enable_flap_detection"},"stop_perfdata_processing":{"name":"Disable performance data processing","category":"Operations","icon":"disabled","mayi_method":"update.command.flapping","view":"monitoring\/naemon_command","enabled_if":"process_performance_data"},"start_perfdata_processing":{"name":"Enable performance data processing","category":"Operations","icon":"enabled","mayi_method":"update.command.flapping","view":"monitoring\/naemon_command","enabled_if":"!process_performance_data"}}},"orm_doctags":{"comment_model":{"get_readable_name":{"depend":["id","is_service","host.name","service.description","type","comment"]}},"downtime_model":{"get_triggered_by_text":{"depend":["triggered_by"]},"get_readable_name":{"depend":["id","is_service","host.name","service.description","start_time","comment"]}},"host_model":{"get_state_text":{"depend":["state","has_been_checked"]},"get_checks_disabled":{"depend":["active_checks_enabled"]},"get_first_group":{"depend":["groups"]},"get_duration":{"depend":["last_state_change"]},"get_comments_count":{"depend":["comments"]},"get_state_type_text":{"depend":["state_type"]},"get_check_type_str":{"depend":["check_type"]},"get_custom_commands":{"depend":["custom_variables"]},"get_config_allowed":{"depend":["contacts"]},"get_source_node":{"depend":["check_source"]},"get_source_type":{"depend":["check_source"]},"get_perf_data":{"depend":["perf_data_raw"]},"get_unacknowledged_problem":{"export":"false","depend":["state","has_been_checked","acknowledged"]},"get_acknowledged_problem":{"export":"false","depend":["state","has_been_checked","acknowledged"]},"get_config_url":{"depend":["name"]},"get_public_custom_variables":{"depend":["custom_variables"]}},"hostgroup_model":{"get_host_stats":{"depend":["name"]},"get_service_stats":{"depend":["name"]},"get_config_url":{"depend":["name"]}},"notification_model":{"get_state_text":{"depend":["state","notification_type"]}},"recurringdowntime_model":{"get_start_time_string":{"depend":["start_time"]},"get_end_time_string":{"depend":["end_time"]},"get_duration_string":{"depend":["duration","fixed"]},"get_duration_arr":{"depend":["duration","fixed"]},"get_objects":{"depend":["id"]},"get_recurrence_text":{"depend":["id"]}},"service_model":{"get_state_text":{"depend":["state","has_been_checked"]},"get_first_group":{"depend":["groups"]},"get_checks_disabled":{"depend":["active_checks_enabled"]},"get_duration":{"depend":["last_state_change"]},"get_comments_count":{"depend":["comments"]},"get_state_type_text":{"depend":["state_type"]},"get_check_type_str":{"depend":["check_type"]},"get_custom_commands":{"depend":["custom_variables"]},"get_config_allowed":{"depend":["contacts"]},"get_source_node":{"depend":["check_source"]},"get_source_type":{"depend":["check_source"]},"get_perf_data":{"depend":["perf_data_raw"]},"get_unacknowledged_problem":{"export":"false","depend":["state","has_been_checked","acknowledged"]},"get_acknowledged_problem":{"export":"false","depend":["state","has_been_checked","acknowledged"]},"get_config_url":{"depend":["host.name","description"]},"get_readable_name":{"depend":["host.name","description"]},"get_public_custom_variables":{"depend":["custom_variables"]}},"servicegroup_model":{"get_service_stats":{"depend":["name"]},"get_config_url":{"depend":["name"]}},"timeperiod_model":{"get_in":{"depend":["is_active"]},"get_exceptions":{"depend":["exceptions_calendar_dates","exceptions_month_date","exceptions_month_day","exceptions_month_week_day","exceptions_week_day"]}}},"orm_structure":{"columns":{"description":["string"],"name":["string"],"table_name":["string"],"type":["string"]},"commands":{"line":["string"],"name":["string"]},"comments":{"author":["string"],"comment":["string"],"entry_time":["time"],"entry_type":["int"],"expire_time":["time"],"expires":["int"],"host":["object","hosts"],"id":["int"],"is_service":["int"],"persistent":["int"],"service":["object","services"],"source":["int"],"type":["int"]},"contactgroups":{"alias":["string"],"members":["list"],"name":["string"]},"contacts":{"address1":["string"],"address2":["string"],"address3":["string"],"address4":["string"],"address5":["string"],"address6":["string"],"alias":["string"],"can_submit_commands":["int"],"custom_variable_names":["list"],"custom_variable_values":["list"],"custom_variables":["dict"],"email":["string"],"host_notification_period":["string"],"host_notifications_enabled":["int"],"in_host_notification_period":["int"],"in_service_notification_period":["int"],"modified_attributes":["int"],"modified_attributes_list":["list"],"name":["string"],"pager":["string"],"service_notification_period":["string"],"service_notifications_enabled":["int"]},"downtimes":{"author":["string"],"comment":["string"],"duration":["int"],"end_time":["time"],"entry_time":["time"],"fixed":["int"],"host":["object","hosts"],"id":["int"],"is_service":["int"],"service":["object","services"],"start_time":["time"],"triggered_by":["int"],"type":["int"]},"hostgroups":{"action_url":["string"],"alias":["string"],"members":["list"],"members_with_state":["list"],"name":["string"],"notes":["string"],"notes_url":["string"],"num_hosts":["int"],"num_hosts_down":["int"],"num_hosts_pending":["int"],"num_hosts_unreach":["int"],"num_hosts_up":["int"],"num_services":["int"],"num_services_crit":["int"],"num_services_hard_crit":["int"],"num_services_hard_ok":["int"],"num_services_hard_unknown":["int"],"num_services_hard_warn":["int"],"num_services_ok":["int"],"num_services_pending":["int"],"num_services_unknown":["int"],"num_services_warn":["int"],"worst_host_state":["int"],"worst_service_hard_state":["int"],"worst_service_state":["int"]},"hosts":{"accept_passive_checks":["int"],"acknowledged":["int"],"acknowledgement_type":["int"],"action_url":["string"],"active_checks_enabled":["int"],"address":["string"],"alias":["string"],"check_command":["string"],"check_flapping_recovery_notification":["int"],"check_freshness":["int"],"check_interval":["float"],"check_options":["int"],"check_period":["string"],"check_source":["string"],"check_type":["int"],"checks_enabled":["int"],"childs":["list"],"comments":["list"],"comments_with_info":["list"],"contact_groups":["list"],"contacts":["list"],"current_attempt":["int"],"current_notification_number":["int"],"custom_variable_names":["list"],"custom_variable_values":["list"],"custom_variables":["dict"],"display_name":["string"],"downtimes":["list"],"downtimes_with_info":["list"],"event_handler":["string"],"event_handler_enabled":["int"],"execution_time":["float"],"filename":["string"],"first_notification_delay":["float"],"flap_detection_enabled":["int"],"groups":["list"],"hard_state":["int"],"has_been_checked":["int"],"high_flap_threshold":["float"],"hourly_value":["int"],"icon_image":["string"],"icon_image_alt":["string"],"in_check_period":["int"],"in_notification_period":["int"],"initial_state":["int"],"is_executing":["int"],"is_flapping":["int"],"last_check":["time"],"last_hard_state":["int"],"last_hard_state_change":["time"],"last_notification":["time"],"last_state":["int"],"last_state_change":["time"],"last_time_down":["time"],"last_time_unreachable":["time"],"last_time_up":["time"],"latency":["float"],"long_plugin_output":["string"],"low_flap_threshold":["float"],"max_check_attempts":["int"],"modified_attributes":["int"],"modified_attributes_list":["list"],"name":["string"],"next_check":["time"],"next_notification":["time"],"no_more_notifications":["int"],"notes":["string"],"notes_url":["string"],"notification_interval":["float"],"notification_period":["string"],"notifications_enabled":["int"],"num_services":["int"],"num_services_crit":["int"],"num_services_hard_crit":["int"],"num_services_hard_ok":["int"],"num_services_hard_unknown":["int"],"num_services_hard_warn":["int"],"num_services_ok":["int"],"num_services_pending":["int"],"num_services_unknown":["int"],"num_services_warn":["int"],"obsess":["int"],"parents":["list"],"pending_flex_downtime":["int"],"percent_state_change":["float"],"perf_data_raw":["string"],"plugin_output":["string"],"pnpgraph_present":["int"],"process_performance_data":["int"],"retry_interval":["float"],"scheduled_downtime_depth":["int"],"services":["list"],"services_with_info":["list"],"services_with_state":["list"],"should_be_scheduled":["int"],"state":["int"],"state_type":["int"],"statusmap_image":["string"],"total_services":["int"],"worst_service_hard_state":["int"],"worst_service_state":["int"]},"servicegroups":{"action_url":["string"],"alias":["string"],"members":["list"],"members_with_state":["list"],"name":["string"],"notes":["string"],"notes_url":["string"],"num_services":["int"],"num_services_crit":["int"],"num_services_hard_crit":["int"],"num_services_hard_ok":["int"],"num_services_hard_unknown":["int"],"num_services_hard_warn":["int"],"num_services_ok":["int"],"num_services_pending":["int"],"num_services_unknown":["int"],"num_services_warn":["int"],"worst_service_state":["int"]},"services":{"accept_passive_checks":["int"],"acknowledged":["int"],"acknowledgement_type":["int"],"action_url":["string"],"active_checks_enabled":["int"],"check_command":["string"],"check_freshness":["int"],"check_interval":["float"],"check_options":["int"],"check_period":["string"],"check_source":["string"],"check_type":["int"],"checks_enabled":["int"],"comments":["list"],"comments_with_info":["list"],"contact_groups":["list"],"contacts":["list"],"current_attempt":["int"],"current_notification_number":["int"],"custom_variable_names":["list"],"custom_variable_values":["list"],"custom_variables":["dict"],"description":["string"],"display_name":["string"],"downtimes":["list"],"downtimes_with_info":["list"],"event_handler":["string"],"event_handler_enabled":["int"],"execution_time":["float"],"first_notification_delay":["float"],"flap_detection_enabled":["int"],"groups":["list"],"has_been_checked":["int"],"high_flap_threshold":["float"],"host":["object","hosts"],"hourly_value":["int"],"icon_image":["string"],"icon_image_alt":["string"],"in_check_period":["int"],"in_notification_period":["int"],"initial_state":["int"],"is_executing":["int"],"is_flapping":["int"],"last_check":["time"],"last_hard_state":["int"],"last_hard_state_change":["time"],"last_notification":["time"],"last_state":["int"],"last_state_change":["time"],"last_time_critical":["time"],"last_time_ok":["time"],"last_time_unknown":["time"],"last_time_warning":["time"],"latency":["float"],"long_plugin_output":["string"],"low_flap_threshold":["float"],"max_check_attempts":["int"],"modified_attributes":["int"],"modified_attributes_list":["list"],"next_check":["time"],"next_notification":["time"],"no_more_notifications":["int"],"notes":["string"],"notes_url":["string"],"notification_interval":["float"],"notification_period":["string"],"notifications_enabled":["int"],"obsess":["int"],"percent_state_change":["float"],"perf_data_raw":["string"],"plugin_output":["string"],"pnpgraph_present":["int"],"process_performance_data":["int"],"retry_interval":["float"],"scheduled_downtime_depth":["int"],"should_be_scheduled":["int"],"state":["int"],"state_type":["int"]},"status":{"accept_passive_host_checks":["int"],"accept_passive_service_checks":["int"],"cached_log_messages":["int"],"check_external_commands":["int"],"check_host_freshness":["int"],"check_service_freshness":["int"],"connections":["int"],"connections_rate":["float"],"enable_event_handlers":["int"],"enable_flap_detection":["int"],"enable_notifications":["int"],"execute_host_checks":["int"],"execute_service_checks":["int"],"forks":["int"],"forks_rate":["float"],"host_checks":["int"],"host_checks_rate":["float"],"interval_length":["int"],"last_log_rotation":["time"],"livecheck_overflows":["int"],"livecheck_overflows_rate":["float"],"livechecks":["int"],"livechecks_rate":["float"],"livestatus_version":["string"],"log_messages":["int"],"log_messages_rate":["float"],"nagios_pid":["int"],"neb_callbacks":["int"],"neb_callbacks_rate":["float"],"num_hosts":["int"],"num_services":["int"],"obsess_over_hosts":["int"],"obsess_over_services":["int"],"process_performance_data":["int"],"program_start":["time"],"program_version":["string"],"requests":["int"],"requests_rate":["float"],"service_checks":["int"],"service_checks_rate":["float"]},"timeperiods":{"name":["string"],"alias":["string"],"days":["list"],"exceptions_calendar_dates":["list"],"exceptions_month_date":["list"],"exceptions_month_day":["list"],"exceptions_month_week_day":["list"],"exceptions_week_day":["list"],"exclusions":["list"],"is_active":["int"]},"notifications":{"instance_id":["int"],"id":["int"],"notification_type":["int"],"start_time":["time"],"end_time":["time"],"contact_name":["string"],"host_name":["string"],"service_description":["string"],"command_name":["string"],"reason_type":["int"],"state":["int"],"output":["string"],"ack_author":["string"],"ack_data":["string"],"escalated":["int"],"contacts_notified":["int"]},"recurring_downtimes":{"id":["int"],"author":["string"],"downtime_type":["string"],"last_update":["int"],"comment":["string"],"start_time":["int"],"end_time":["int"],"duration":["int"],"fixed":["int"],"weekdays":["list"],"months":["list"],"start_date":["string"],"end_date":["string"],"recurrence":["string"],"recurrence_on":["string"],"recurrence_ends":["string"],"exclude_days":["string"]}},"orm_table_classes":{"columns":{"object":"Column_Model","set":"ColumnSet_Model","pool":"ColumnPool_Model"},"commands":{"object":"Command_Model","set":"CommandSet_Model","pool":"CommandPool_Model"},"comments":{"object":"Comment_Model","set":"CommentSet_Model","pool":"CommentPool_Model"},"contactgroups":{"object":"ContactGroup_Model","set":"ContactGroupSet_Model","pool":"ContactGroupPool_Model"},"contacts":{"object":"Contact_Model","set":"ContactSet_Model","pool":"ContactPool_Model"},"downtimes":{"object":"Downtime_Model","set":"DowntimeSet_Model","pool":"DowntimePool_Model"},"hostgroups":{"object":"HostGroup_Model","set":"HostGroupSet_Model","pool":"HostGroupPool_Model"},"hosts":{"object":"Host_Model","set":"HostSet_Model","pool":"HostPool_Model"},"servicegroups":{"object":"ServiceGroup_Model","set":"ServiceGroupSet_Model","pool":"ServiceGroupPool_Model"},"services":{"object":"Service_Model","set":"ServiceSet_Model","pool":"ServicePool_Model"},"status":{"object":"Status_Model","set":"StatusSet_Model","pool":"StatusPool_Model"},"timeperiods":{"object":"TimePeriod_Model","set":"TimePeriodSet_Model","pool":"TimePeriodPool_Model"},"notifications":{"object":"Notification_Model","set":"NotificationSet_Model","pool":"NotificationPool_Model"},"recurring_downtimes":{"object":"RecurringDowntime_Model","set":"RecurringDowntimeSet_Model","pool":"RecurringDowntimePool_Model"}}});



/*******************
 * From src: modules/monitoring/src/js/lsfilter_renderer_buttons.js
 *******************/
listview_renderer_buttons.recurring_downtimes = [
	function () { return icon16('sign-add', 'Add new downtime', link('recurring_downtime')).append('New') }
];



/*******************
 * From src: modules/monitoring/src/js/lsfilter_renderer_table.js
 *******************/
/*******************************************************************************
 * Table renderer
 ******************************************************************************/

listview_renderer_table.hosts = {
	"state" : {
		"header" : '',
		"depends" : [ 'state_text', 'name', 'key'],
		"sort" : [ 'has_been_checked desc', 'state desc' ],
		"cell" : function(args) {
			return $('<td class="icon obj_properties" />')
					.append(
							icon16('shield-' + args.obj.state_text, args.obj.state_text)
					)
					.addClass(args.obj.state_text)
					.attr('data-table', 'hosts')
					.attr('data-object', args.obj.key);
		}
	},
	"name" : {
		"header" : _('Name'),
		"depends" : [ 'name', 'icon_image', 'address' ],
		"sort" : [ 'name' ],
		"cell" : function(args) {
			var cell = $('<td />');
			cell.append(extinfo_link({
				host : args.obj.name
			}).attr('title', args.obj.address).update_text(args.obj.name));
			if (args.obj.icon_image)
				cell.append(icon(args.obj.icon_image, extinfo_link({
					host : args.obj.name
				})).css('float', 'right'));

			return cell;
		}
	},
	"alias" : {
		"header" : _('Alias'),
		"depends" : [ 'alias' ],
		"sort" : [ 'alias' ],
		"cell" : function(args) {
			return $('<td />').update_text(args.obj.alias);
		}
	},
	"checktype" : {
		"header" : _('Checks'),
		"depends" : [ 'checks_enabled', 'accept_passive_checks' ],
		"sort" : [ 'checks_enabled desc', 'accept_passive_checks desc' ],
		"cell" : function(args) {
			var cell = $('<td />');
			if (args.obj.checks_enabled) {
				cell.append(
					span_icon('icon-angle-down', "Active checks enabled")
				);
			} else {
				cell.append(
					span_icon('icon-angle-down', "Active checks disabled")
					.addClass('disabled')
				);
			}
			if (args.obj.accept_passive_checks) {
				cell.append(
					span_icon('icon-angle-up', "Passive checks enabled")
					.css('margin-left', '-8px')
				);
			} else {
				cell.append(
					span_icon('icon-angle-up', "Passive checks disabled")
					.addClass('disabled')
					.css('margin-left', '-8px')
				);
			}
			return cell;
		}
	},
	"status" : {
		"header" : _('Status'),
		"depends" : [ 'name', 'acknowledged', 'notifications_enabled',
				'checks_disabled', 'is_flapping', 'scheduled_downtime_depth',
				'pnpgraph_present', 'comments_count' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />');

			if (args.obj.pnpgraph_present > 0) {

				var pnp_link = icon16('pnp', _('Show performance graph'), link(
						'pnp', {
							"srv" : "_HOST_",
							"host" : args.obj.name
						}));

				pnp_link.attr('data-popover',
					'pnp:' + args.obj.name
				);

				cell.append(pnp_link);

			}

			if (args.obj.acknowledged)
				cell.append(icon16('acknowledged', _('Acknowledged')));

			if (!args.obj.notifications_enabled)
				cell.append(icon16('notify-disabled', 'Notification disabled'));

			if (args.obj.is_flapping) // FIXME: Needs icon in compass
				cell.append(icon16('flapping', _('Flapping')));

			if (args.obj.scheduled_downtime_depth > 0)
				cell.append(icon16('scheduled-downtime',
						_('Scheduled Downtime')));

			if (args.obj.comments_count > 0)
				cell.append(comment_icon(args.obj.name, null));

			return cell;
		}
	},
	"actions" : {
		"header" : _('Actions'),
		"depends" : [ 'name', 'action_url', 'config_url', 'notes_url',
				'config_allowed' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />');

			// FIXME: icon for service-details
			cell.append(icon16('service-details',
					_('View service details for this host'),
					link_query('[services] host.name = "' + args.obj.name + '"' // FIXME:
					// escape
					)));

			if (args.obj.action_url) {
				cell.append(icon16('host-actions',
						_('Perform extra host actions'), $('<a />').attr(
								'href', args.obj.action_url).attr('target',
								_action_url_target)));
			}

			if (args.obj.config_url && args.obj.config_allowed)
				cell.append(icon16('nacoma', _('Configure this host'), $(
						'<a />').attr('href', args.obj.config_url)));

			if (args.obj.notes_url) {
				cell.append(icon16('host-notes', _('View extra host notes'), $(
						'<a />').attr('href', args.obj.notes_url).attr(
						'target', _notes_url_target)));
			}

			return cell;
		}
	},
	"last_check" : {
		"header" : _('Last Checked'),
		"depends" : [ 'last_check' ],
		"sort" : [ 'last_check' ],
		"cell" : function(args) {
			return $('<td />').text(format_timestamp(args.obj.last_check));
		}
	},
	"duration" : {
		"header" : _('Duration'),
		"depends" : [ 'duration' ],
		"sort" : [ 'last_state_change desc' ],
		"cell" : function(args) {
			return $('<td />').text(format_interval(args.obj.duration));
		}
	},
	"status_information" : {
		"header" : _('Status Information'),
		"depends" : [ 'plugin_output' ],
		"sort" : [ 'plugin_output' ],
		"cell" : function(args) {
			return $('<td class="restricted-output" />').update_text(
					args.obj.plugin_output);
		}
	},
	"services_num_all" : {
		"header" : function () {return icon12('shield-info').addClass('header-icon')},
		"depends" : [ 'num_services', 'name' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />').css('text-align', 'center');
			if (args.obj.num_services > 0) {
				cell.append(link_query(
						'[services] host.name = "' + args.obj.name + '"')
						.append(args.obj.num_services));
				cell.addClass('cell_svccnt_all');
				cell.addClass('cell_svccnt');
			}
			return cell;
		}
	},
	"services_num_ok" : {
		"header" : function () {return icon12('shield-ok').addClass('header-icon')},
		"depends" : [ 'num_services_ok' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />').css('text-align', 'center');
			if (args.obj.num_services_ok > 0) {
				cell.append(link_query(
						'[services] host.name = "' + args.obj.name
								+ '" and state=0 and has_been_checked!=0')
						.append(args.obj.num_services_ok));
				cell.addClass('cell_svccnt_ok');
				cell.addClass('cell_svccnt');
			}
			return cell;
		}
	},
	"services_num_warning" : {
		"header" : function () {return icon12('shield-warning').addClass('header-icon')},
		"depends" : [ 'num_services_warn' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />').css('text-align', 'center');
			if (args.obj.num_services_warn > 0) {
				cell.append(link_query(
						'[services] host.name = "' + args.obj.name
								+ '" and state=1 and has_been_checked!=0')
						.append(args.obj.num_services_warn));
				cell.addClass('cell_svccnt_warning');
				cell.addClass('cell_svccnt');
			}
			return cell;
		}
	},
	"services_num_critical" : {
		"header" : function () {return icon12('shield-critical').addClass('header-icon')},
		"depends" : [ 'num_services_crit' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />').css('text-align', 'center');
			if (args.obj.num_services_crit > 0) {
				cell.append(link_query(
						'[services] host.name = "' + args.obj.name
								+ '" and state=2 and has_been_checked!=0')
						.append(args.obj.num_services_crit));
				cell.addClass('cell_svccnt_critical');
				cell.addClass('cell_svccnt');
			}
			return cell;
		}
	},
	"services_num_unknown" : {
		"header" : function () {return icon12('shield-unknown').addClass('header-icon')},
		"depends" : [ 'num_services_unknown' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />').css('text-align', 'center');
			if (args.obj.num_services_unknown > 0) {
				cell.append(link_query(
						'[services] host.name = "' + args.obj.name
								+ '" and state=3 and has_been_checked!=0')
						.append(args.obj.num_services_unknown));
				cell.addClass('cell_svccnt_unknown');
				cell.addClass('cell_svccnt');
			}
			return cell;
		}
	},
	"services_num_pending" : {
		"header" : function () {return icon12('shield-pending').addClass('header-icon')},
		"depends" : [ 'num_services_pending' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />').css('text-align', 'center');
			if (args.obj.num_services_pending > 0) {
				cell.append(link_query(
						'[services] host.name = "' + args.obj.name
								+ '" and has_been_checked=0').append(
						args.obj.num_services_pending));
				cell.addClass('cell_svccnt_pending');
				cell.addClass('cell_svccnt');
			}
			return cell;
		}
	}
};

listview_renderer_table.services = {
	"host_state" : {
		"order" : 10,
		"header" : '',
		"depends" : [ 'host.state_text', 'host.name' ],
		"sort" : [ 'host.state' ],
		"cell" : function(args) {
			if (args.obj.host
					&& (!args.last_obj.host || args.obj.host.name != args.last_obj.host.name)) {
				return $('<td class="icon obj_properties" />')
					.append(
						icon16('shield-' + args.obj.host.state_text, args.obj.host.state_text)
					)
					.addClass(args.obj.host.state_text)
					.attr('data-table', 'hosts')
					.attr('data-object', args.obj.host.name);

			} else {
				return $('<td class="icon" />').addClass('listview-empty-cell');
			}
		}
	},
	"host_name" : {
		"order" : 20,
		"header" : _('Host Name'),
		"depends" : [ 'host.name', 'host.icon_image', 'host.address' ],
		"sort" : [ 'host.name', 'description' ],
		"cell" : function(args) {
			var cell = $('<td />');

			if (args.obj.host
					&& (!args.last_obj.host || args.obj.host.name != args.last_obj.host.name)) {
				cell.append(extinfo_link({
					host : args.obj.host.name
				}).attr('title', args.obj.host.address).update_text(
						args.obj.host.name));

				if (args.obj.host.icon_image)
					cell.append(icon(args.obj.host.icon_image, extinfo_link({
						host : args.obj.host.name
					})).css('float', 'right'));

			} else {
				cell.addClass('listview-empty-cell');
			}

			return cell;
		}
	},
	"host_actions" : {
		"order" : 30,
		"header" : _('Host Actions'),
		"depends" : [ 'host.name', 'host.action_url', 'host.config_url',
				'host.notes_url', 'host.config_allowed' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />');

			if (args.obj.host
					&& (!args.last_obj.host || args.obj.host.name != args.last_obj.host.name)) {
				cell.append(icon16('service-details',
						_('View service details for this host'),
						link_query('[services] host.name = "'
								+ args.obj.host.name + '"' // FIXME:
								// escape
						)));

				if (args.obj.host.action_url)
					cell.append(icon16('host-actions',
							_('Perform extra host actions'), $('<a />').attr(
									'href', args.obj.host.action_url)));

				if (args.obj.host.config_url && args.obj.host.config_allowed)
					cell.append(icon16('nacoma', _('Configure this host'), $(
							'<a />').attr('href', args.obj.host.config_url)));

				if (args.obj.host.notes_url)
					cell.append(icon16('host-notes',
							_('View extra host notes'), $('<a />').attr('href',
									args.obj.host.notes_url)));
			} else {
				cell.addClass('listview-empty-cell');
			}

			return cell;
		}
	},
	"state" : {
		"order" : 40,
		"header" : '',
		"depends" : [ 'state_text', 'description', 'host.name', 'key'],
		"sort" : [ 'has_been_checked desc', 'state desc' ],
		"cell" : function(args) {
			return $(
					'<td class="icon svc_obj_properties"><span class="icon-16 x16-shield-'
							+ args.obj.state_text + '"></span></td>').addClass(
					args.obj.state_text)
					.attr('data-table', 'services')
					.attr('data-object', args.obj.key);
		}
	},
	"description" : {
		"order" : 50,
		"header" : _('Service'),
		"depends" : [ 'host.name', 'description', 'icon_image' ],
		"sort" : [ 'description' ],
		"cell" : function(args) {

			var cell = $('<td />');

			cell.append(extinfo_link({
				host : args.obj.host.name,
				service : args.obj.description
			}).update_text(args.obj.description));

			if (args.obj.icon_image) {
				cell.append(icon(args.obj.icon_image, extinfo_link({
					host : args.obj.host.name,
					service : args.obj.description
				})).css('float', 'right'));
			}

			return cell;

		}
	},
	"checktype" : {
		"order": 55,
		"header" : _('Checks'),
		"depends" : [ 'checks_enabled', 'accept_passive_checks' ],
		"sort" : [ 'checks_enabled desc', 'accept_passive_checks desc' ],
		"cell" : function(args) {
			var cell = $('<td />');
			if (args.obj.checks_enabled) {
				cell.append(
					span_icon('icon-angle-down', 'Active checks enabled')
				);
			} else {
				cell.append(
					span_icon('icon-angle-down', 'Active checks disabled')
					.addClass('disabled')
				);
			}
			if (args.obj.accept_passive_checks) {
				cell.append(
					span_icon('icon-angle-up', 'Passive checks enabled')
					.css('margin-left', '-4px')
				);
			} else {
				cell.append(
					span_icon('icon-angle-up', 'Passive checks disabled')
					.addClass('disabled')
					.css('margin-left', '-4px')
				);
			}
			return cell;
		}
	},
	"status" : {
		"order" : 60,
		"header" : _('Status'),
		"depends" : [ 'host.name', 'description', 'pnpgraph_present',
				'acknowledged', 'comments_count', 'notifications_enabled',
				'checks_disabled', 'is_flapping', 'scheduled_downtime_depth',
				'host.scheduled_downtime_depth' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />');

			if (args.obj.pnpgraph_present > 0) {

				var pnp_link = icon16('pnp', _('Show performance graph'), link(
						'pnp', {
							"srv" : args.obj.description,
							"host" : args.obj.host.name
						}));

				pnp_link.attr('data-popover',
					'image:/monitor/op5/pnp/image?host=' + args.obj.host.name + '&srv=' + args.obj.description + '&view=0&source=0'
				);

				cell.append(pnp_link);

			}

			if (args.obj.acknowledged)
				cell.append(icon16('acknowledged', _('Acknowledged')));

			if (!args.obj.notifications_enabled)
				cell.append(icon16('notify-disabled',
						_('Notification disabled')));

			if (args.obj.is_flapping) // FIXME: Needs icon in compass
				cell.append(icon16('flapping', _('Flapping')));

			if ((args.obj.scheduled_downtime_depth > 0)
					|| (args.obj.host.scheduled_downtime_depth > 0))
				cell.append(icon16('scheduled-downtime',
						_('Scheduled Downtime')));

			if (args.obj.comments_count > 0)
				cell.append(comment_icon(args.obj.host.name,
						args.obj.description));

			return cell;
		}
	},
	"actions" : {
		"order" : 70,
		"header" : _('Actions'),
		"depends" : [ 'action_url', 'config_url', 'notes_url', 'config_allowed' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />');

			if (args.obj.action_url) {
				cell.append(icon16('host-actions',
						_('Perform extra service actions'), $('<a />').attr({
							'href': args.obj.action_url,
							'target': _action_url_target
						})));
			}

			if (args.obj.config_url && args.obj.config_allowed)
				cell.append(icon16('nacoma', _('Configure this service'), $(
						'<a />').attr('href', args.obj.config_url)));

			if (args.obj.notes_url)
				cell.append(icon16('host-notes', _('View extra service notes'),
						$('<a />').attr('href', args.obj.notes_url)));

			return cell;
		}
	},
	"last_check" : {
		"order" : 80,
		"header" : _('Last Checked'),
		"depends" : [ 'last_check' ],
		"sort" : [ 'last_check' ],
		"cell" : function(args) {
			return $('<td />').text(format_timestamp(args.obj.last_check));
		}
	},
	"duration" : {
		"order" : 90,
		"header" : _('Duration'),
		"depends" : [ 'duration' ],
		"sort" : [ 'last_state_change desc' ],
		"cell" : function(args) {
			return $('<td />').text(format_interval(args.obj.duration));
		}
	},
	"attempt" : {
		"order" : 100,
		"header" : _('Attempt'),
		"depends" : [ 'current_attempt', 'max_check_attempts' ],
		"sort" : [ 'current_attempt' ],
		"cell" : function(args) {
			return $('<td />').text(
					args.obj.current_attempt + "/"
							+ args.obj.max_check_attempts);
		}
	},
	"status_information" : {
		"order" : 110,
		"header" : _('Status Information'),
		"depends" : [ 'plugin_output' ],
		"sort" : [ 'plugin_output' ],
		"cell" : function(args) {
			return $('<td class="restricted-output" />').update_text(
					args.obj.plugin_output);
		}
	}
};

listview_renderer_table.hostgroups = {
	"name" : {
		"header" : _('Host Group'),
		"depends" : [ 'alias', 'name' ],
		"sort" : [ 'alias', 'name' ],
		"cell" : function(args) {
			var cell = $('<td />');
			cell.append(link_query('[hosts] groups >= "' + args.obj.name + '"')
					.update_text(args.obj.alias + ' (' + args.obj.name + ')'));
			return cell;
		}
	},
	"actions" : {
		"header" : _('Actions'),
		"depends" : [],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />');
			cell.append(icon16('extended-information', _('Actions'),
					extinfo_link({
						hostgroup : args.obj.name
					}).attr('title', 'Status information for ' + args.obj.name)));
			return cell;
		}
	},
	"host_status_summary" : {
		"header" : _('Host Status Summary'),
		"depends" : [ 'host_stats' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td / >');
			cell.append(render_host_status_summary(args.obj.host_stats));
			return cell;
		}
	},
	"service_status_summary" : {
		"header" : _('Service Status Summary'),
		"depends" : [ 'service_stats' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td / >');
			cell.append(render_service_status_summary(args.obj.service_stats));
			return cell;
		}
	}
};

listview_renderer_table.servicegroups = {
	"name" : {
		"header" : _('Service Group'),
		"depends" : [ 'alias', 'name' ],
		"sort" : [ 'alias', 'name' ],
		"cell" : function(args) {
			var cell = $('<td />');
			cell.append(link_query('[services] groups >= "' + args.obj.name + '"')
					.update_text(args.obj.alias + ' (' + args.obj.name + ')'));
			return cell;
		}
	},
	"actions" : {
		"header" : _('Actions'),
		"depends" : [],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />');
			cell.append(icon16('extended-information', _('Actions'),
					extinfo_link({
						servicegroup : args.obj.name
					}).attr('title', 'Status information for ' + args.obj.name)));
			return cell;
		}
	},
	"service_status_summary" : {
		"header" : _('Service Status Summary'),
		"depends" : [ 'service_stats' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td / >');
			cell.append(render_service_status_summary(args.obj.service_stats));
			return cell;
		}
	}
};

listview_renderer_table.comments = {
	"id" : {
		"header" : _('ID'),
		"depends" : [ 'id' ],
		"sort" : [ 'id' ],
		"cell" : function(args) {
			return $('<td />').text(args.obj.id);
		}
	},
	"object_type" : {
		"header" : _('Type'),
		"depends" : [ 'is_service' ],
		"sort" : false,
		"cell" : function(args) {
			return $('<td />').text(args.obj.is_service ? 'Service' : 'Host');
		}
	},
	"host_state" : {
		"header" : '',
		"depends" : [ 'host.state_text' ],
		"sort" : [ 'host.state' ],
		"cell" : function(args) {
			return $('<td />').append(
					icon16('shield-' + args.obj.host.state_text,
							args.obj.host.state_text));

		}
	},
	"host_name" : {
		"header" : _('Host Name'),
		"depends" : [ 'host.name', 'host.icon_image' ],
		"sort" : [ 'host.name' ],
		"cell" : function(args) {
			var cell = $('<td />');
			cell.append(extinfo_link({
				host : args.obj.host.name
			}).update_text(args.obj.host.name));

			if (args.obj.host.icon_image)
				cell.append(icon(args.obj.host.icon_image, extinfo_link({
					host : args.obj.host.name
				})).css('float', 'right'));

			return cell;
		}
	},
	"service_state" : {
		"header" : '',
		"depends" : [ 'service.state_text', 'service.description' ],
		"sort" : [ 'service.state' ],
		"cell" : function(args) {
			if (!args.obj.service.description)
				return $('<td />');

			return $('<td><span class="icon-16 x16-shield-'
					+ args.obj.service.state_text + '"></span></td>');
		}
	},
	"service_description" : {
		"header" : _('Service'),
		"depends" : [ 'host.name', 'service.description' ],
		"sort" : [ 'service.description' ],
		"cell" : function(args) {
			if (!args.obj.service.description)
				return $('<td />');
			return $('<td />').append(extinfo_link({
				host : args.obj.host.name,
				service : args.obj.service.description
			}).update_text(args.obj.service.description));
		}
	},
	"entry_time" : {
		"header" : _('Entry Time'),
		"depends" : [ 'entry_time' ],
		"sort" : [ 'entry_time' ],
		"cell" : function(args) {
			return $('<td />').text(format_timestamp(args.obj.entry_time));
		}
	},
	"author" : {
		"header" : _('Author'),
		"depends" : [ 'author' ],
		"sort" : [ 'author' ],
		"cell" : function(args) {
			return $('<td />').text(args.obj.author);
		}
	},
	"comment" : {
		"header" : _('Comment'),
		"depends" : [ 'comment' ],
		"sort" : [ 'comment' ],
		"cell" : function(args) {
			return $('<td class="restricted-output"/>').update_text(args.obj.comment);
		}
	},
	"id" : {
		"header" : _('ID'),
		"depends" : [ 'id' ],
		"sort" : [ 'id' ],
		"cell" : function(args) {
			return $('<td />').text(args.obj.id);
		}
	},
	"persistent" : {
		"header" : _('Persistent'),
		"depends" : [ 'persistent' ],
		"sort" : [ 'persistent' ],
		"cell" : function(args) {
			var cell = $('<td />');
			if (args.obj.persistent)
				cell.text(_('Yes'));
			else
				cell.text(_('No'));
			return cell;
		}
	},
	"entry_type" : {
		"header" : _('Type'),
		"depends" : [ 'entry_type' ],
		"sort" : [ 'entry_type' ],
		"cell" : function(args) {
			var cell = $('<td />');
			switch (args.obj.entry_type) {
			case 1:
				cell.text(_("User comment"));
				break;
			case 2:
				cell.text(_("Scheduled downtime"));
				break;
			case 3:
				cell.text(_("Flapping"));
				break;
			case 4:
				cell.text(_("Acknowledgement"));
				break;
			}
			return cell;
		}
	},
	"expires" : {
		"header" : _('Expires'),
		"depends" : [ 'expires', 'expire_time' ],
		"sort" : [ 'expires', 'expire_time' ],
		"cell" : function(args) {
			var cell = $('<td />');
			if (args.obj.expires)
				cell.text(args.obj.expire_time);
			else
				cell.text(_('N/A'));
			return cell;
		}
	},
	"actions" : {
		"header" : _('Actions'),
		"depends" : [ 'id', 'entry_type', 'is_service' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />');
			cell.append(
				icon16(
					'delete-comment',
					_('Delete comment'),
					link(
						'cmd',
						{
							'command': 'delete',
							'table': 'comments',
							'object': args.obj.id+";"+Number(args.obj.is_service)
						}
					)
						.attr('title', 'Delete comment')
						.attr('class', 'action_delete_comment')
				)
			);
			return cell;
		}
	}
};
listview_renderer_table.downtimes = {
	"id" : {
		"header" : _('ID'),
		"depends" : [ 'id' ],
		"sort" : [ 'id' ],
		"cell" : function(args) {
			return $('<td />').text(args.obj.id);
		}
	},
	"object_type" : {
		"header" : _('Type'),
		"depends" : [ 'is_service' ],
		"sort" : false,
		"cell" : function(args) {
			return $('<td />').text(args.obj.is_service ? 'Service' : 'Host');
		}
	},
	"host_state" : {
		"header" : '',
		"depends" : [ 'host.state_text' ],
		"sort" : [ 'host.state' ],
		"cell" : function(args) {
			return $('<td />').append(
					icon16('shield-' + args.obj.host.state_text,
							args.obj.host.state_text));

		}
	},
	"host_name" : {
		"header" : _('Host Name'),
		"depends" : [ 'host.name', 'host.icon_image' ],
		"sort" : [ 'host.name' ],
		"cell" : function(args) {
			var cell = $('<td />');
			cell.append(extinfo_link({
				host : args.obj.host.name
			}).update_text(args.obj.host.name));

			if (args.obj.host.icon_image)
				cell.append(icon(args.obj.host.icon_image, extinfo_link({
					host : args.obj.host.name
				})).css('float', 'right'));

			return cell;
		}
	},
	"service_state" : {
		"header" : '',
		"depends" : [ 'service.state_text', 'service.description' ],
		"sort" : [ 'service.state' ],
		"cell" : function(args) {
			if (!args.obj.service.description)
				return $('<td />');

			return $('<td><span class="icon-16 x16-shield-'
					+ args.obj.service.state_text + '"></span></td>');
		}
	},
	"service_description" : {
		"header" : _('Service'),
		"depends" : [ 'host.name', 'service.description' ],
		"sort" : [ 'service.description' ],
		"cell" : function(args) {
			if (!args.obj.service.description)
				return $('<td />');
			return $('<td />').append(extinfo_link({
				host : args.obj.host.name,
				service : args.obj.service.description
			}).update_text(args.obj.service.description));
		}
	},
	"entry_time" : {
		"header" : _('Entry Time'),
		"depends" : [ 'entry_time' ],
		"sort" : [ 'entry_time' ],
		"cell" : function(args) {
			return $('<td />').text(format_timestamp(args.obj.entry_time));
		}
	},
	"author" : {
		"header" : _('Author'),
		"depends" : [ 'author' ],
		"sort" : [ 'author' ],
		"cell" : function(args) {
			return $('<td />').text(args.obj.author);
		}
	},
	"comment" : {
		"header" : _('Comment'),
		"depends" : [ 'comment' ],
		"sort" : [ 'comment' ],
		"cell" : function(args) {
			return $('<td />').update_text(args.obj.comment);
		}
	},
	"start_time" : {
		"header" : _("Start Time"),
		"depends" : [ 'start_time' ],
		"sort" : [ 'start_time' ],
		"cell" : function(args) {
			return $('<td />').text(format_timestamp(args.obj.start_time));
		}
	},
	"end_time" : {
		"header" : _("End Time"),
		"depends" : [ 'end_time' ],
		"sort" : [ 'end_time' ],
		"cell" : function(args) {
			return $('<td />').text(format_timestamp(args.obj.end_time));
		}
	},
	"type" : {
		"header" : _("Type"),
		"depends" : [ 'fixed' ],
		"sort" : [ 'fixed' ],
		"cell" : function(args) {
			return $('<td />')
					.text(args.obj.fixed ? _("Fixed") : _("Flexible"));
		}
	},
	"duration" : {
		"header" : _("Duration"),
		"depends" : [ 'start_time', 'end_time', 'duration' ],
		"sort" : false,
		"cell" : function(args) {
			return $('<td />').text(
					args.obj.fixed ? format_interval(args.obj.end_time - args.obj.start_time) : (args.obj.duration/3600)+"h");
		}
	},
	"triggered_by" : {
		"header" : _("Triggered by"),
		"depends" : [ 'triggered_by_text' ],
		"sort" : [ 'triggered_by' ],
		"cell" : function(args) {
			return $('<td />').text(args.obj.triggered_by_text);
		}
	},
	"actions" : {
		"header" : _('Actions'),
		"depends" : [ 'id', 'is_service', 'host.name', 'service.description' ],
		"sort" : false,
		"cell" : function(args) {
			var cell = $('<td />');

			// Delete
			cell.append(
				icon16(
					'delete-downtime',
					_("Delete/cancel this scheduled downtime entry"),
					link(
						'cmd',
						{
							'command': 'delete',
							'table': 'downtimes',
							'object': args.obj.id+";"+Number(args.obj.is_service)
						}
					)
				)
			);

			// Schedule recurring
			var recurring_args = {
				host : args.obj.host.name
			};
			if (args.obj.service.description) {
				recurring_args.service = args.obj.service.description;
			}
			cell.append(icon16('recurring-downtime', _('Recurring downtime'),
					link('recurring_downtime', recurring_args)));

			return cell;
		}
	}
};

listview_renderer_table.contacts = {
	"name" : {
		"header" : _('Name'),
		"depends" : [ 'name' ],
		"sort" : [ 'name' ],
		"cell" : function(args) {
			return $('<td />').update_text(args.obj.name);
		}
	},
	"alias" : {
		"header" : _('Alias'),
		"depends" : [ 'alias' ],
		"sort" : [ 'alias' ],
		"cell" : function(args) {
			return $('<td />').update_text(args.obj.alias);
		}
	},
	"email" : {
		"header" : _('Email'),
		"depends" : [ 'email' ],
		"sort" : [ 'email' ],
		"cell" : function(args) {
			return $('<td />').link_email(args.obj.email);
		}
	},
	"pager" : {
		"header" : _('Pager'),
		"depends" : [ 'pager' ],
		"sort" : [ 'pager' ],
		"cell" : function(args) {
			return $('<td />').update_text(args.obj.pager);
		}
	}
};

listview_renderer_table.notifications = {
	"state" : {
		"header" : '',
		"depends" : [ 'state_text' ],
		"sort" : [ 'notification_type', 'state' ],
		"cell" : function(args) {
			return $('<td class="icon" />')
					.append(
							icon16('shield-' + args.obj.state_text,
									args.obj.state_text));

		}
	},
	"host_name" : {
		"header" : _('Host'),
		"depends" : [ 'host_name' ],
		"sort" : [ 'host_name', 'service_description' ],
		"cell" : function(args) {
			var cell = $('<td />');
			cell.append(extinfo_link({
				host : args.obj.host_name
			}).update_text(args.obj.host_name));

			return cell;
		}
	},
	"service_description" : {
		"header" : _('Service'),
		"depends" : [ 'host_name', 'service_description' ],
		"sort" : [ 'service_description' ],
		"cell" : function(args) {
			var cell = $('<td />');
			cell.append(extinfo_link({
				host : args.obj.host_name,
				service : args.obj.service_description
			}).update_text(args.obj.service_description));

			return cell;
		}
	},
	"time" : {
		"header" : _('Time'),
		"depends" : [ 'start_time' ],
		"sort" : [ 'start_time' ],
		"cell" : function(args) {
			return $('<td />').text(format_timestamp(args.obj.start_time));
		}
	},
	"contact" : {
		"header" : _('Contact'),
		"depends" : [ 'contact_name' ],
		"sort" : [ 'contact_name' ],
		"cell" : function(args) {
			return $('<td />').text(args.obj.contact_name);
		}
	},
	"notification_command" : {
		"header" : _('Notification Command'),
		"depends" : [ 'command_name' ],
		"sort" : [ 'command_name' ],
		"cell" : function(args) {
			return $('<td />').text(args.obj.command_name);
		}
	},
	"status_information" : {
		"header" : _('Status Information'),
		"depends" : [ 'output' ],
		"sort" : [ 'output' ],
		"cell" : function(args) {
			return $('<td class="restricted-output" />').update_text(args.obj.output);
		}
	}
};

listview_renderer_table.recurring_downtimes = {
	"downtime_type": {
		"header": _('Downtime type'),
		"depends": ['downtime_type'],
		"sort": ['downtime_type'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.downtime_type);
		}
	},
	"objects": {
		"header": _('Objects'),
		"depends": ['objects'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.objects.join(', '));
		}
	},
	"author": {
		"header": _('Author'),
		"depends": ['author'],
		"sort": ['author'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.author);
		}
	},
	"comment": {
		"header": _('Comment'),
		"depends": ['comment'],
		"sort": ['comment'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.comment);
		}
	},
	"start_time": {
		"header": _('Start time'),
		"depends": ['start_time_string'],
		"sort": ['start_time'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.start_time_string);
		}
	},
	"end_time": {
		"header": _('End time'),
		"depends": ['end_time_string'],
		"sort": ['end_time'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.end_time_string);
		}
	},
	"duration": {
		"header": _('Duration'),
		"depends": ['duration_string'],
		"sort": ['duration'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.duration_string);
		}
	},
	"fixed": {
		"header": _('Fixed?'),
		"depends": ['fixed'],
		"sort": ['fixed'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.fixed ? _("Fixed") : _("Flexible"));
		}
	},
	"Recurrence": {
        "header": _('Recurrence'),
        "depends": ['recurrence_text', 'weekdays', 'months'],
        "cell": function(args) {
            if(args.obj.recurrence_text != ''){
             	return $('<td />').update_text(args.obj.recurrence_text);
            }else{
                _escape_html_tags = false;
                return $('<td />').update_text('Weekdays: '+$.map(args.obj.weekdays, function (x) {return JSON.parse(Date.abbrDayNames)[x];}).join(', ')+'<br>Months: '+ $.map(args.obj.months, function (x) {return JSON.parse(Date.abbrMonthNames)[x-1];}).join(', '));
            }
        }
    },
	"actions": {
		"header": _('Actions'),
		"depends": ['id'],
		"cell": function(args) {
			var cell = $('<td />');
			cell.append(icon16('edit',
				_('Edit schedule'),
				link('recurring_downtime/index/' + args.obj.id)
					.attr('title', 'Edit schedule')
			));
			cell.append(icon16('delete-doc',
				_('Delete schedule'),
				link('recurring_downtime/delete/')
					.data('recurring-id', args.obj.id)
					.addClass('recurring_delete')
					.attr('title', 'Delete schedule')
			));
			return cell;
		}
	},
};

listview_renderer_table.commands = {
	"name": {
		"header": _('Name'),
		"depends": ['name'],
		"sort": ['name'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.name);
		}
	},
	"line": {
		"header": _('Shell command line'),
		"depends": ['line'],
		"sort": ['line'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.line);
		}
	}
};

listview_renderer_table.timeperiods = {
	"name": {
		"header": _('Name'),
		"depends": ['name'],
		"sort": ['name'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.name);
		}
	},
	"alias": {
		"header": _('Alias'),
		"depends": ['alias'],
		"sort": ['alias'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.alias);
		}
	},
	"days": {
		"header": _('Day schedule'),
		"depends": ['days'],
		"sort": false,
		"cell": function(args) {
			var cell = $('<td />');
			var i;
			var sub_list = $('<table />');
			var days = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
			for(i=0;i<7;i++) {
				var day = args.obj.days[i];

				/* Build timerange definition */
				var range_def = "";
				var tr_i;
				var have_range = false;
				for(tr_i=0;tr_i<day.length;tr_i+=2) {
					if(range_def)
						range_def += ", ";
					range_def += "" + (day[tr_i]/3600.0) + "-" + (day[tr_i+1]/3600.0);
					have_range = true;
				}

				if( have_range ) {
					sub_list.append(
							$('<tr />')
							.append($('<td />').text(days[i]))
							.append($('<td />').text(range_def))
						);
				}
			}
			cell.append(sub_list);
			return cell;
		}
	},
	"exceptions": {
		"header": _('Exceptions'),
		"depends": ['exceptions'],
		"sort": false,
		"cell": function(args) {
			var cell = $('<td />');
			var i;
			var sub_list = $('<table />');
			var months = ['January','February','March','April','May','June','July','August','September','October','November','December'];
			var days = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
			var format_timerange = function(tr) {
			};
			for (i = 0; i < args.obj.exceptions.length; i++) {
				var ex = args.obj.exceptions[i];

				/* Build date definition */
				var date_def = "";
				switch (ex.type) {
				case 'calendar_date':
					date_def += ex.syear + "-" + (ex.smon + 1) + "-"
							+ ex.smday;
					if ((ex.syear != ex.eyear) || (ex.smon != ex.emon)
							|| (ex.smday != ex.emday))
						date_def += " - " + ex.eyear + "-" + (ex.emon + 1)
								+ "-" + ex.emday;
					break;
				case 'month_date':
					date_def += months[ex.smon] + " " + ex.smday;
					if ((ex.smon != ex.emon) || (ex.smday != ex.emday))
						date_def += " - " + months[ex.emon + 1] + " "
								+ ex.emday;
					break;
				case 'month_day':
					date_def += "day " + ex.smday;
					if ((ex.smday != ex.emday))
						date_def += " - " + ex.emday;
					break;
				case 'month_week_day':
					date_def += days[ex.swday] + " " + ex.swday_offset + " "
							+ months[ex.smon];
					if ((ex.swday != ex.ewday)
							|| (ex.swday_offset != ex.ewday_offset)
							|| (ex.smon != ex.emon))
						date_def += " - " + days[ex.ewday] + " " + ex.ewday_offset
								+ " " + months[ex.emon];
					break;
				case 'week_day':
					date_def += days[ex.swday] + " " + ex.swday_offset;
					if ((ex.swday != ex.ewday)
							|| (ex.swday_offset != ex.ewday_offset))
						date_def += " - " + days[ex.ewday] + " " + ex.ewday_offset;
					break;
				}
				if (ex.skip_interval > 1) {
					date_def += " / " + ex.skip_interval;
				}

				/* Build timerange definition */
				var range_def = "";
				var tr_i;
				for(tr_i=0;tr_i<ex.times.length;tr_i+=2) {
					if(range_def)
						range_def += ", ";
					range_def += "" + (ex.times[tr_i]/3600.0) + "-" + (ex.times[tr_i+1]/3600.0);
				}

				sub_list.append(
						$('<tr />')
						.append($('<td />').text(date_def))
						.append($('<td />').text(range_def))
					);
			}
			cell.append(sub_list);
			return cell;
		}
	},
	"exclusions": {
		"header": _('Exclusions'),
		"depends": ['exclusions'],
		"sort": false,
		"cell": function(args) {
			var cell = $('<td />');
			var i;
			var sub_list = $('<ul />');
			for(i=0;i<args.obj.exclusions.length;i++) {
				sub_list.append($('<li />').text(args.obj.exclusions[i]));
			}
			cell.append(sub_list);
			return cell;
		}
	},
	"in": {
		"header": _('Currently active'),
		"depends": ['is_active'],
		"sort": ['is_active'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.is_active ? _('Yes') : _('No'));
		}
	}
};

listview_renderer_table.contactgroups = {
	"name": {
		"header": _('Name'),
		"depends": ['name'],
		"sort": ['name'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.name);
		}
	},
	"alias": {
		"header": _('Alias'),
		"depends": ['alias'],
		"sort": ['alias'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.alias);
		}
	},
	"members": {
		"header": _('Members'),
		"depends": ['members'],
		"sort": ['members'],
		"cell": function(args) {
			return $('<td />').update_text(args.obj.members.join(', '));
		}
	}
};



/*******************
 * From src: modules/monitoring/src/js/lsfilter_renderer_totals.js
 *******************/

/*******************************************************************************
 * Totals renderer
 ******************************************************************************/

listview_renderer_totals['count'] = function(cnt) {
	var container = $('<li class="extra_toolbar_category" />');
	container.append(_("Count") + ": &nbsp; ");
	container.append(icon16('shield-info', _("Matching")));
	container.append(cnt);
	return container;
};
listview_renderer_totals["host_all"] = function(cnt) {
	var container = $('<li class="extra_toolbar_category" />');
	container.append(_("Hosts") + ": &nbsp; ");
	container.append(icon16('host', _("Hosts total")));
	container.append(cnt);
	return container;
};
listview_renderer_totals["host_state_up"] = function(cnt) {
	var container = $('<li />');
	container.append(icon16(((cnt == 0) ? 'shield-not' : 'shield') + '-up',
			_("Hosts up")));
	container.append(cnt);
	return container;
};
listview_renderer_totals["host_state_down"] = function(cnt) {
	var container = $('<li />');
	container.append(icon16(((cnt == 0) ? 'shield-not' : 'shield')
			+ '-down', _("Hosts down")));
	container.append(cnt);
	return container;
};
listview_renderer_totals["host_state_unreachable"] = function(cnt) {
	var container = $('<li />');
	container.append(icon16(((cnt == 0) ? 'shield-not' : 'shield')
			+ '-unreachable', _("Hosts unreachable")));
	container.append(cnt);
	return container;
};
listview_renderer_totals["host_pending"] = function(cnt) {
	var container = $('<li />');
	container.append(icon16(((cnt == 0) ? 'shield-not' : 'shield')
			+ '-pending', _("Hosts pending")));
	container.append(cnt);
	return container;
};

listview_renderer_totals["service_all"] = function(cnt) {
	var container = $('<li class="extra_toolbar_category" />');
	container.append(_("Services") + ": &nbsp; ");
	container.append(icon16('shield-info', _("Services total")));
	container.append(cnt);
	return container;
};
listview_renderer_totals["service_state_ok"] = function(cnt) {
	var container = $('<li />');
	container.append(icon16(((cnt == 0) ? 'shield-not' : 'shield') + '-ok',
			_("Services ok")));
	container.append(cnt);
	return container;
};
listview_renderer_totals["service_state_warning"] = function(cnt) {
	var container = $('<li />');
	container.append(icon16(((cnt == 0) ? 'shield-not' : 'shield')
			+ '-warning', _("Services warning")));
	container.append(cnt);
	return container;
};
listview_renderer_totals["service_state_critical"] = function(cnt) {
	var container = $('<li />');
	container.append(icon16(((cnt == 0) ? 'shield-not' : 'shield')
			+ '-critical', _("Services critical")));
	container.append(cnt);
	return container;
};
listview_renderer_totals["service_state_unknown"] = function(cnt) {
	var container = $('<li />');
	container.append(icon16(((cnt == 0) ? 'shield-not' : 'shield')
			+ '-unknown', _("Services unknown")));
	container.append(cnt);
	return container;
};
listview_renderer_totals["service_pending"] = function(cnt) {
	var container = $('<li />');
	container.append(icon16(((cnt == 0) ? 'shield-not' : 'shield')
			+ '-pending', _("Services pending")));
	container.append(cnt);
	return container;
};



/*******************
 * From src: modules/monitoring/src/js/pnp/pnp.js
 *******************/
$(document).ready(function () {
	$('#iframe').load(function() {
		$(this).focus();
		$(this.contentDocument).find('.ui-widget-header tr').each(function () {
			$(this).append('<td align="right"><a href="#" class="default" title="Make default graph" alt="Make default graph"><img src="' + _site_domain + '/application/views/icons/x16/shield-ok.png"/></a></td>');
			$(this).find('.default').click(function() {
				var src = $(this).closest('div').next('div').find('img').attr('src');
				var match = src.match(/\?(.*)&view=(\d)&source=(\d)/);
				$.ajax(
					_site_domain + _index_page + '/pnp/pnp_default/',
					{
						data: {
							param: match[1],
							view: match[2],
							source: match[3],
							csrf_token: _csrf_token
						},
						success: function () {
							Notify.message(_settings_msg, {type: "error"});
						},
						error: function () {
							Notify.message(_error_header, {type: "error"});
						},
						type: 'POST'
					}
				);
				return false;
			});
		});
	});
});



/*******************
 * From src: modules/monitoring/src/js/showlog.js
 *******************/
$(document).ready(function() {
	init_datepicker();
	init_timepicker();
});


